@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "wb_live_schema_tree.h"
@@ -205,6 +209,7 @@ void LiveSchemaTree::IndexData::copy(LSTData* other) {
     this->columns.assign(pother->columns.begin(), pother->columns.end());
     this->type = pother->type;
     this->unique = pother->unique;
+    this->visible = pother->visible;
   }
 }
 
@@ -214,8 +219,8 @@ std::string LiveSchemaTree::IndexData::get_details(bool full, const mforms::Tree
   if (details.empty()) {
     details = "<table style=\"border: none; border-collapse: collapse;\">";
     details += strfmt(LST_INFO_BOX_DETAIL_ROW.c_str(), "Type", externalize_token(type).c_str());
-    std::string unique_str = unique ? "Yes" : "No";
-    details += strfmt(LST_INFO_BOX_DETAIL_ROW.c_str(), "Unique", unique_str.c_str());
+    details += strfmt(LST_INFO_BOX_DETAIL_ROW.c_str(), "Unique", unique ? "Yes" : "No");
+    details += strfmt(LST_INFO_BOX_DETAIL_ROW.c_str(), "Visible", visible ? "Yes" : "No");
     details += strfmt(LST_INFO_BOX_DETAIL_ROW.c_str(), "Columns", columns[0].c_str());
 
     for (std::size_t index = 1; index < columns.size(); index++)
@@ -881,7 +886,7 @@ bool LiveSchemaTree::update_node_children(mforms::TreeNodeRef parent, base::Stri
 }
 
 std::string LiveSchemaTree::get_field_description(const mforms::TreeNodeRef& node) {
-  std::string text("");
+  std::string text;
   mforms::TreeNodeRef temp_node = node;
 
   try {
@@ -1491,19 +1496,22 @@ bec::MenuItemList LiveSchemaTree::get_popup_items_for_nodes(const std::list<mfor
     if (type == Schema) {
       bec::MenuItem active_schema_item;
       active_schema_item.caption = _("Set as Default Schema");
-      active_schema_item.name = "set_active_schema";
+      active_schema_item.internalName = "set_active_schema";
+      active_schema_item.accessibilityName = "Set Active Schema";
       active_schema_item.enabled = nodes.size() == 1;
 
       bec::MenuItem filter_schema_item;
       filter_schema_item.caption = _("Filter to This Schema");
-      filter_schema_item.name = "filter_schema";
+      filter_schema_item.internalName = "filter_schema";
+      filter_schema_item.accessibilityName = "Filter Schema";
       filter_schema_item.enabled = nodes.size() == 1;
 
       items.push_back(active_schema_item);
       items.push_back(filter_schema_item);
       bec::MenuItem item;
       item.type = MenuSeparator;
-      item.name = "builtins_separator"; // this indicates where plugins should start adding their menu items
+      item.internalName = "builtins_separator"; // this indicates where plugins should start adding their menu items
+      item.accessibilityName = "Separator";
       items.push_back(item);
     } else if (type == Table || type == View || type == TableColumn || type == ViewColumn || type == ViewCollection ||
                type == ColumnCollection) {
@@ -1521,24 +1529,28 @@ bec::MenuItemList LiveSchemaTree::get_popup_items_for_nodes(const std::list<mfor
         }
         view_item.caption = caption;
       }
-      view_item.name = "select_data";
+      view_item.internalName = "select_data";
+      view_item.accessibilityName = "Select Data";
       view_item.enabled = !nodes.empty() && (nodes.size() == 1 || (type == TableColumn || type == ViewColumn));
       items.push_back(view_item);
       bec::MenuItem item;
       item.type = MenuSeparator;
-      item.name = "builtins_separator"; // this indicates where plugins should start adding their menu items
+      item.internalName = "builtins_separator"; // this indicates where plugins should start adding their menu items
+      item.accessibilityName = "Separator";
       items.push_back(item);
     }
   }
   {
     bec::MenuItem item;
     item.type = MenuSeparator;
-    item.name = "bottom_plugins_separator"; // this indicates where plugins should start adding their menu items
+    item.internalName = "bottom_plugins_separator";
+    item.accessibilityName = "Separator"; // this indicates where plugins should start adding their menu items
     items.push_back(item);
 
     item.type = MenuAction;
     item.caption = _("Refresh All");
-    item.name = "refresh";
+    item.internalName = "refresh";
+    item.accessibilityName = "Refresh";
     items.push_back(item);
   }
 
@@ -2065,7 +2077,7 @@ void LiveSchemaTree::node_activated(mforms::TreeNodeRef node, int column) {
               break;
             default:
               delegate->tree_activate_objects("activate", changes);
-#ifndef _WIN32
+#ifndef _MSC_VER
               node->toggle();
 #endif
               break;
@@ -2092,7 +2104,7 @@ void LiveSchemaTree::node_activated(mforms::TreeNodeRef node, int column) {
               case -3:
                 delegate->tree_activate_objects("select_data", changes);
                 break;
-#ifndef _WIN32
+#ifndef _MSC_VER
               default:
                 node->toggle();
                 break;
@@ -2131,7 +2143,7 @@ void LiveSchemaTree::node_activated(mforms::TreeNodeRef node, int column) {
         break;
     }
   }
-#ifndef _WIN32
+#ifndef _MSC_VER
   else
     node->toggle();
 #endif
