@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2007, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "workbench/wb_backend_public_interface.h"
@@ -46,6 +50,7 @@ namespace mforms {
 
 namespace wb {
   class SimpleSidebar;
+  class AdvancedSidebar;
 }
 
 class MYSQLWBBACKEND_PUBLIC_FUNC SqlEditorTreeController
@@ -71,7 +76,7 @@ private:
 
   SqlEditorForm *_owner;
 
-  wb::SimpleSidebar *_schema_side_bar;
+  wb::AdvancedSidebar *_schema_side_bar;
   wb::SimpleSidebar *_admin_side_bar;
   mforms::TabView *_task_tabview;
   mforms::Box *_taskbar_box;
@@ -83,7 +88,6 @@ private:
   GrtThreadedTask::Ref live_schema_fetch_task;
   GrtThreadedTask::Ref live_schemata_refresh_task;
   bool _is_refreshing_schema_tree;
-  bool _unified_mode;
 
   bool _use_show_procedure;
 
@@ -97,8 +101,10 @@ private:
   // Observer
   virtual void handle_grt_notification(const std::string &name, grt::ObjectRef sender, grt::DictRef info);
 
+  void updateColors();
+
   // LiveSchemaTree::FetchDelegate
-  virtual std::list<std::string> fetch_schema_list();
+  virtual std::vector<std::string> fetch_schema_list();
   virtual bool fetch_data_for_filter(const std::string &schema_filter, const std::string &object_filter,
                                      const wb::LiveSchemaTree::NewSchemaContentArrivedSlot &arrived_slot);
   virtual bool fetch_schema_contents(const std::string &schema_name,
