@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2010, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "sqlide/wb_sql_editor_form.h"
@@ -105,6 +109,7 @@ bool WbOptions::parse_args(array<String ^> ^ args, String ^ app_path) {
       Logger::LogInfo("WBContext managed", String::Format("Exiting with rc {0} after parsing arguments\n", rc));
       ret = false;
     }
+    inner->analyzeCommandLineArguments();
   } catch (std::exception &exc) {
     Logger::LogInfo("WBContext managed",
                     String::Format("Exiting with error message: {0}\n", CppStringToNative(exc.what())));
@@ -307,12 +312,6 @@ String ^ WbContext::get_active_context() {
 
 //--------------------------------------------------------------------------------------------------
 
-void WbContext::show_output() {
-  WBContextUI::get()->show_output();
-}
-
-//--------------------------------------------------------------------------------------------------
-
 void WbContext::close_gui_plugin(IntPtr handle) {
   WBContextUI::get()->get_wb()->close_gui_plugin((NativeHandle)handle.ToPointer());
 }
@@ -571,9 +570,9 @@ bool WbContext::save_changes() {
 
 //--------------------------------------------------------------------------------------------------
 
-void WbContext::flush_idle_tasks() {
+void WbContext::flush_idle_tasks(bool force) {
   try {
-    WBContextUI::get()->get_wb()->flush_idle_tasks();
+    WBContextUI::get()->get_wb()->flush_idle_tasks(force);
   } catch (std::exception *ex) {
     throw gcnew MySQL::Grt::BackendException(ex);
   } catch (std::exception &ex) {
