@@ -1,18 +1,24 @@
 /*
- * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 of the License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "base/string_utilities.h"
@@ -106,7 +112,7 @@ static std::string showFileDialog(const std::string &type, const std::string &ti
     panel.title = @(title.c_str());
     panel.allowedFileTypes = fileTypes;
 
-    if ([panel runModal] == NSFileHandlingPanelOKButton)
+    if ([panel runModal] == NSModalResponseOK)
       return (panel.URL.path).UTF8String;
   } else if (type == "save") {
     NSSavePanel *panel = [NSSavePanel savePanel];
@@ -115,7 +121,7 @@ static std::string showFileDialog(const std::string &type, const std::string &ti
 
     panel.allowedFileTypes = fileTypes;
 
-    if ([panel runModal] == NSFileHandlingPanelOKButton)
+    if ([panel runModal] == NSModalResponseOK)
       return (panel.URL.path).UTF8String;
   }
 
@@ -160,7 +166,7 @@ static NativeHandle windowOpenPlugin(grt::Module *ownerModule, const std::string
       NSAlert *alert = [NSAlert new];
       alert.messageText = @"Missing Plugin";
       alert.informativeText = [NSString stringWithFormat: @"The plugin %s could not be found.", shlib.c_str()];
-      alert.alertStyle = NSCriticalAlertStyle;
+      alert.alertStyle = NSAlertStyleCritical;
       [alert addButtonWithTitle: @"Close"];
       [alert runModal];
 
@@ -177,7 +183,7 @@ static NativeHandle windowOpenPlugin(grt::Module *ownerModule, const std::string
         NSAlert *alert = [NSAlert new];
         alert.messageText = @"Error Loading Plugin";
         alert.informativeText = [NSString stringWithFormat: @"The plugin %s could not be loaded. See log file for details", shlib.c_str()];
-        alert.alertStyle = NSCriticalAlertStyle;
+        alert.alertStyle = NSAlertStyleCritical;
         [alert addButtonWithTitle: @"Close"];
         [alert runModal];
 
@@ -193,7 +199,7 @@ static NativeHandle windowOpenPlugin(grt::Module *ownerModule, const std::string
       alert.messageText = @"Error Opening Plugin";
       alert.informativeText = [NSString
         stringWithFormat: @"The plugin %s does not contain the published object %s", shlib.c_str(), class_name.c_str()];
-      alert.alertStyle = NSCriticalAlertStyle;
+      alert.alertStyle = NSAlertStyleCritical;
       [alert addButtonWithTitle: @"Close"];
       [alert runModal];
 
@@ -217,7 +223,7 @@ static NativeHandle windowOpenPlugin(grt::Module *ownerModule, const std::string
             id editor = [existingPanel pluginEditor];
 
             if ([editor respondsToSelector: @selector(reinitWithArguments:)]) {
-              id oldIdentifier = [editor identifier];
+              id oldIdentifier = [editor panelId];
 
               [controller closeBottomPanelWithIdentifier: oldIdentifier];
               [editor reinitWithArguments: args];
@@ -444,8 +450,10 @@ static bool validate_select_all() {
 static bool validate_delete() {
   NSResponder *responder = NSApp.keyWindow.firstResponder;
   SEL selector = NSSelectorFromString(@"canDeleteItem:");
-  if ([responder respondsToSelector: selector])
-    return [responder performSelector:selector withObject: nil];
+  if ([responder respondsToSelector: selector]) {
+    #pragma clang diagnostic ignored "-Warc-performSelector-leaks"
+    return [responder performSelector: selector withObject: nil];
+  }
 
   if ([responder respondsToSelector: @selector(selectedRange)]) {
     NSRange textRange = [(id)NSApp.keyWindow.firstResponder selectedRange];
@@ -585,8 +593,9 @@ static bool validate_find(MainWindowController *controller) {
 static void call_undo(MainWindowController *controller) {
   id firstResponder = NSApp.keyWindow.firstResponder;
 
-  if ([firstResponder respondsToSelector: @selector(undo:)])
-    [firstResponder tryToPerform: @selector(undo:) with: nil];
+  SEL selector = NSSelectorFromString(@"undo:");
+  if ([firstResponder respondsToSelector: selector])
+    [firstResponder tryToPerform: selector with: nil];
   else if ([firstResponder isKindOfClass: [NSTextView class]])
     return [[firstResponder undoManager] undo];
   else if (wb::WBContextUI::get()->get_active_main_form())
@@ -610,8 +619,9 @@ static bool validate_undo(MainWindowController *controller) {
 static void call_redo(MainWindowController *controller) {
   id firstResponder = NSApp.keyWindow.firstResponder;
 
-  if ([firstResponder respondsToSelector: @selector(redo:)])
-    [firstResponder tryToPerform: @selector(redo:) with: nil];
+  SEL selector = NSSelectorFromString(@"redo:");
+  if ([firstResponder respondsToSelector: selector])
+    [firstResponder tryToPerform: selector with: nil];
   else if ([firstResponder isKindOfClass: [NSTextView class]])
     return [[firstResponder undoManager] redo];
   else if (wb::WBContextUI::get()->get_active_main_form())
@@ -704,7 +714,7 @@ static bool validate_redo(MainWindowController *controller) {
 
 static void flush_main_thread() {
   // flush stuff that could be called with performSelectorOnMainThread:
-  [[NSRunLoop currentRunLoop] acceptInputForMode:NSModalPanelRunLoopMode beforeDate: [NSDate date]];
+  [[NSRunLoop currentRunLoop] acceptInputForMode: NSDefaultRunLoopMode beforeDate: [NSDate date]];
 }
 
 - (BOOL)application:(NSApplication *)theApplication openFile:(NSString *)filename {
@@ -725,7 +735,7 @@ static void flush_main_thread() {
   _initFinished = YES;
   [[NSNotificationCenter defaultCenter] addObserver: self
                                            selector: @selector(windowDidBecomeKey:)
-                                               name:NSWindowDidBecomeKeyNotification
+                                               name: NSWindowDidBecomeKeyNotification
                                              object: nil];
 }
 
@@ -744,7 +754,12 @@ static void flush_main_thread() {
 
 - (void)applicationDidBecomeActive:(NSNotification *)notification {
   base::NotificationInfo info;
-  base::NotificationCenter::get()->send("GNApplicationActivated", NULL, info);
+  base::NotificationCenter::get()->send("GNApplicationActivated", nullptr, info);
+}
+
+- (void)applicationDidResignActive:(NSNotification *)notification {
+  base::NotificationInfo info;
+  base::NotificationCenter::get()->send("GNApplicationDeactivated", nullptr, info);
 }
 
 static NSString *applicationSupportFolder() {
@@ -803,7 +818,7 @@ static NSString *applicationSupportFolder() {
 
     wb::WBContextUI::get()->init(&wbcallbacks, _options);
 
-    _wb->flush_idle_tasks();
+    _wb->flush_idle_tasks(false);
   } catch (std::exception &exc) {
     MShowCPPException(exc);
   }
@@ -967,12 +982,12 @@ static void init_mforms() {
   if (!_showingUnhandledException) {
     _showingUnhandledException = YES;
     try {
-      _wb->flush_idle_tasks();
+      _wb->flush_idle_tasks(false);
     } catch (const std::exception &exc) {
       NSAlert *alert = [NSAlert new];
       alert.messageText = @"Unhandled Exception";
       alert.informativeText = [NSString stringWithFormat:@"An unhandled exception has occurred: %s", exc.what()];
-      alert.alertStyle = NSCriticalAlertStyle;
+      alert.alertStyle = NSAlertStyleCritical;
       [alert addButtonWithTitle:@"Close"];
       [alert runModal];
     }
@@ -983,7 +998,7 @@ static void init_mforms() {
 - (void)idleTasks:(NSTimer *)timer {
   static NSArray *modes = nil;
   if (!modes)
-    modes = @[ NSDefaultRunLoopMode, NSModalPanelRunLoopMode ];
+    modes = @[NSDefaultRunLoopMode, NSModalPanelRunLoopMode];
 
   // if we call flush_idle_tasks() directly here, we could get blocked by a plugin with a
   // modal loop. In that case, the timer would not get fired again until the modal loop
@@ -991,7 +1006,8 @@ static void init_mforms() {
   [[NSRunLoop currentRunLoop] performSelector: @selector(flushIdleTasks:)
                                        target: self
                                      argument: self
-                                        order: 0 modes: modes];
+                                        order: 0
+                                        modes: modes];
 }
 
 - (void)requestRefresh {
