@@ -1,23 +1,27 @@
 /*
- * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
-#include "grtpp.h"
+#include "grt.h"
 #include "grt/grt_value_inspector.h"
 
 #import "WBObjectPropertiesController.h"
@@ -32,7 +36,7 @@
   for (NSUInteger i = 1; i < result.length; ++i) {
     NSRange r = NSMakeRange(i, 1);
     NSString *one = [result substringWithRange: r];
-    if ([one isEqualToString: [one uppercaseString]]) {
+    if ([one isEqualToString: one.uppercaseString]) {
       NSString* pre = [result substringToIndex: i];
       NSString* post = [result substringFromIndex: i];
       result = [NSString stringWithFormat: @"%@ %@", pre, post];
@@ -53,7 +57,6 @@
   NSCell* mColorCell;
   NSButtonCell * mCheckBoxCell;
 
-  wb::WBContextUI *_wbui;
   bec::ValueInspectorBE* mValueInspector;
 }
 
@@ -112,12 +115,12 @@ objectValueForTableColumn: (NSTableColumn*) aTableColumn
     node.append(rowIndex);
     
     std::string s;
-    if ([[aTableColumn identifier] isEqualToString: @"name"]) {
+    if ([aTableColumn.identifier isEqualToString: @"name"]) {
       mValueInspector->get_field(node, ::bec::ValueInspectorBE::Name, s);
       NSString* name = @(s.c_str());
-      name = [name stringBySplittingCamelCase];
+      name = name.stringBySplittingCamelCase;
       name = [name stringByAppendingString: @":"];
-      retVal = [name capitalizedString];
+      retVal = name.capitalizedString;
     }
     else {
       mValueInspector->get_field(node, ::bec::ValueInspectorBE::Value, s);
@@ -162,7 +165,7 @@ dataCellForTableColumn: (NSTableColumn*) tableColumn
 {
   NSCell* cell = nil;
   
-  if ([[tableColumn identifier] isEqualToString: @"value"]) {
+  if ([tableColumn.identifier isEqualToString: @"value"]) {
     PropertyType pt = [self propertyTypeForRowIndex: rowIndex];
     if (pt == PROPERTY_TYPE_COLOR) {
       cell = mColorCell;
@@ -173,7 +176,7 @@ dataCellForTableColumn: (NSTableColumn*) tableColumn
   }
   
   if (cell == nil) {
-    cell = [tableColumn dataCell];
+    cell = tableColumn.dataCell;
   }
   
   return cell;
@@ -212,14 +215,14 @@ shouldEditTableColumn: (NSTableColumn*) aTableColumn
   std::string s;
   mValueInspector->get_field(node, ::bec::ValueInspectorBE::Value, s);
   NSString* hex = @(s.c_str());
-  if ([hex length] > 1) {
+  if (hex.length > 1) {
     hex = [hex substringFromIndex: 1];
   }
 
-  if ([hex length] == 6) {
+  if (hex.length == 6) {
     NSColorPanel* scp = [NSColorPanel sharedColorPanel];
     NSColor* color = [WBColorCell colorWithHexString: hex];
-    [scp setColor: color];
+    scp.color = color;
     
     hasColor = YES;
   }
@@ -231,10 +234,10 @@ shouldEditTableColumn: (NSTableColumn*) aTableColumn
 
 - (void) userDoubleClick: (id) sender;
 {
-  NSInteger rowIndex = [mTableView selectedRow];
+  NSInteger rowIndex = mTableView.selectedRow;
   PropertyType pt = [self propertyTypeForRowIndex: rowIndex];
   if (pt == PROPERTY_TYPE_COLOR) {
-    [self updateColorPickerPanelWithColorAtRowIndex: rowIndex];
+    [self updateColorPickerPanelWithColorAtRowIndex: (int)rowIndex];
     {
       NSColorPanel* scp = [NSColorPanel sharedColorPanel];
       [scp setTarget: self];
@@ -251,8 +254,8 @@ shouldEditTableColumn: (NSTableColumn*) aTableColumn
 {
   NSColor* c = [sender color];
   NSString* hex = [WBColorCell hexStringWithColor: c];
-  const char* cStr = [hex UTF8String];
-  NSInteger rowIndex = [mTableView selectedRow];
+  const char* cStr = hex.UTF8String;
+  NSInteger rowIndex = mTableView.selectedRow;
   if (rowIndex >= 0)
   {
     bec::NodeId node;
@@ -276,13 +279,13 @@ shouldEditTableColumn: (NSTableColumn*) aTableColumn
   
   if (form != nil) {
     std::vector<std::string> items;
-    mValueInspector = _wbui->create_inspector_for_selection(form, items);
+    mValueInspector = wb::WBContextUI::get()->create_inspector_for_selection(form, items);
     
     // Update color of color picker to match new selection.
-    NSInteger rowIndex = [mTableView selectedRow];
+    NSInteger rowIndex = mTableView.selectedRow;
     PropertyType pt = [self propertyTypeForRowIndex: rowIndex];
     if (pt == PROPERTY_TYPE_COLOR) {
-      [self updateColorPickerPanelWithColorAtRowIndex: rowIndex];
+      [self updateColorPickerPanelWithColorAtRowIndex: (int)rowIndex];
     }
   }
   
@@ -290,14 +293,6 @@ shouldEditTableColumn: (NSTableColumn*) aTableColumn
 }
 
 
-
-- (void) setWBContext: (wb::WBContextUI*) be;
-{
-  _wbui = be;
-}
-
-
-
 #pragma mark Create + Destroy
 
 - (void) awakeFromNib;
@@ -307,11 +302,11 @@ shouldEditTableColumn: (NSTableColumn*) aTableColumn
   
   mCheckBoxCell = [NSButtonCell new];
   [mCheckBoxCell setButtonType: NSSwitchButton];
-  [mCheckBoxCell setControlSize: NSSmallControlSize];
-  [mCheckBoxCell setTitle: @""];
+  mCheckBoxCell.controlSize = NSControlSizeSmall;
+  mCheckBoxCell.title = @"";
   
-  [mTableView setTarget: self];
-  [mTableView setDoubleAction: @selector(userDoubleClick:)];
+  mTableView.target = self;
+  mTableView.doubleAction = @selector(userDoubleClick:);
 }
 
 - (void) dealloc
