@@ -1,20 +1,24 @@
-/* 
- * Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
+ *
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 using System;
@@ -353,9 +357,9 @@ namespace MySQL.GUI.Workbench
           case Overview.NodeType.Item:
             // find the object in its container
             NodeIdWrapper parent = wbOverview.get_parent(node);
-            if (listsByNode.ContainsKey(parent.repr()))
+            if (listsByNode.ContainsKey(parent.toString()))
             {
-              ListView list = listsByNode[parent.repr()];
+              ListView list = listsByNode[parent.toString()];
               UpdateListViewNode(node, list);
             }
             break;
@@ -368,9 +372,9 @@ namespace MySQL.GUI.Workbench
           case Overview.NodeType.Group:
           {
             // schema tabs
-            if (panelsByNode.ContainsKey(wbOverview.get_parent(node).repr()))
+            if (panelsByNode.ContainsKey(wbOverview.get_parent(node).toString()))
             {
-              CollapsingPanel panel = panelsByNode[wbOverview.get_parent(node).repr()];
+              CollapsingPanel panel = panelsByNode[wbOverview.get_parent(node).toString()];
 
               panel.Refresh();
               panel.Update();
@@ -408,7 +412,7 @@ namespace MySQL.GUI.Workbench
         }
         else if (nodeType == (int)Overview.NodeType.Group)
         {
-          CollapsingPanel panel = panelsByNode[node.repr()];
+          CollapsingPanel panel = panelsByNode[node.toString()];
         }
         else if (nodeType == (int)Overview.NodeType.Division)
         {
@@ -436,9 +440,9 @@ namespace MySQL.GUI.Workbench
 
     private void RefreshGroupTabs(NodeIdWrapper node)
     {
-      if (panelsByNode.ContainsKey(node.repr()))
+      if (panelsByNode.ContainsKey(node.toString()))
       {
-        CollapsingPanel panel = panelsByNode[node.repr()];
+        CollapsingPanel panel = panelsByNode[node.toString()];
 
         panel.SuspendLayout();
 
@@ -453,9 +457,9 @@ namespace MySQL.GUI.Workbench
 
     private void RefreshItemList(NodeIdWrapper node, Overview.NodeType nodeType)
     {
-      if (listsByNode.ContainsKey(node.repr()))
+      if (listsByNode.ContainsKey(node.toString()))
       {
-        ListView list = listsByNode[node.repr()];
+        ListView list = listsByNode[node.toString()];
 
         if (nodeType == Overview.NodeType.Section)
         {
@@ -525,7 +529,7 @@ namespace MySQL.GUI.Workbench
           overviewPanel.Padding = new Padding(12, 4, 0, 0);
           overviewPanel.BackColor = Color.White;
 
-          panelsByNode[panelNodeId.repr()] = overviewPanel;
+          panelsByNode[panelNodeId.toString()] = overviewPanel;
 
           overviewPanel.Tag = CreateIdentifier(panelNodeId);
 
@@ -691,9 +695,9 @@ namespace MySQL.GUI.Workbench
       NodeIdWrapper parent = wbOverview.get_parent(node);
       int index = node.end();
 
-      if (listsByNode.ContainsKey(parent.repr()))
+      if (listsByNode.ContainsKey(parent.toString()))
       {
-        ListView list = listsByNode[parent.repr()];
+        ListView list = listsByNode[parent.toString()];
 
         list.Focus();
         list.SelectedIndices.Clear();
@@ -766,7 +770,7 @@ namespace MySQL.GUI.Workbench
           {
             // If the child entry is an item thean we don't have any intermediate structure.
             ListView sectionListview = GetSectionListview(panelNodeId, overviewPanel, false, displayMode, "", "");
-            cacheListview(panelNodeId.repr(), sectionListview);
+            cacheListview(panelNodeId.toString(), sectionListview);
             PopulateListView(panelNodeId, sectionListview);
             break;
           }
@@ -1130,7 +1134,7 @@ namespace MySQL.GUI.Workbench
                   String info = "(" + childCount + ((childCount == 1) ? " item" : " items") + ")";
                   ListView sectionListview = GetSectionListview(sectionNodeId, overviewPanel, true, displayMode, caption, info);
 
-                  cacheListview(sectionNodeId.repr(), sectionListview);
+                  cacheListview(sectionNodeId.toString(), sectionListview);
 
                   PopulateListViewColumns(sectionNodeId, sectionListview, displayMode);
 
@@ -1144,7 +1148,7 @@ namespace MySQL.GUI.Workbench
               {
                 // If there are no sections, simple add the items.
                 ListView sectionListview = GetSectionListview(parentNodeId, overviewPanel, false, displayMode, "", "");
-                cacheListview(parentNodeId.repr(), sectionListview);
+                cacheListview(parentNodeId.toString(), sectionListview);
                 PopulateListView(parentNodeId, sectionListview);
               }
             }
@@ -1683,7 +1687,7 @@ namespace MySQL.GUI.Workbench
 
         contentSplitContainer.Panel2Collapsed = true;
         contentSplitContainer.SplitterWidth = 6; 
-        contentSplitContainer.Panel2MinSize = 300;
+        contentSplitContainer.Panel2MinSize = 370;
       }
       finally
       {
