@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2005, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2005, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include <glib/gstdio.h>
@@ -23,17 +27,13 @@
 #include <fstream>
 #include <vector>
 
+#include "base/log.h"
 #include "base/common.h"
 #include "base/string_utilities.h"
-
-// Log calls only used on Linux atm (causing a warning on Win + Mac).
-#if !defined(_WIN32) && !defined(__APPLE__)
-#include "base/log.h"
-DEFAULT_LOG_DOMAIN(DOMAIN_BASE)
-#endif
+#include "wb_version.h"
 
 // Windows includes
-#ifdef _WIN32
+#ifdef _MSC_VER
 #include <windows.h>
 #include <direct.h>
 #include <tchar.h>
@@ -76,6 +76,8 @@ DEFAULT_LOG_DOMAIN(DOMAIN_BASE)
 #include "base/file_functions.h"
 #include "base/util_functions.h"
 
+DEFAULT_LOG_DOMAIN(DOMAIN_BASE)
+
 struct hardware_info {
   std::string _cpu;
   std::string _clock;
@@ -90,7 +92,7 @@ static void __sappend(char **str, int *ressize, int *reslen, const char *sbegin,
     *ressize += count + 100;
     *str = (char *)g_realloc(*str, *ressize);
   }
-#ifdef _WIN32
+#ifdef _MSC_VER
   strncpy_s(*str + *reslen, *reslen, sbegin, count);
 #else
   strncpy(*str + *reslen, sbegin, count);
@@ -164,7 +166,7 @@ char *auto_line_break(const char *txt, unsigned int width, char sep) {
     w++;
 
     if (w > width) {
-#if defined(__WIN__) || defined(_WIN32) || defined(_WIN64)
+#if defined(_MSC_VER)
       dst[p + o] = '\r';
       dst[p + o + 1] = '\n';
 
@@ -216,7 +218,7 @@ char *str_toupper(char *str) {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-#if defined(__WIN__) || defined(_WIN32) || defined(_WIN64)
+#if defined(_MSC_VER)
 
 #define BUFSIZE 256
 #define VER_SUITE_WH_SERVER 0x00008000
@@ -352,7 +354,7 @@ std::string get_local_hardware_info() {
   return hardware_string;
 }
 
-#else /* !__WIN__ */
+#else
 
 #if defined(__APPLE__) && defined(__MACH__)
 
@@ -369,6 +371,8 @@ std::string get_local_os_name() {
   *dot_position = 0;
   int version = base::atoi<int>(info.release, 0);
   switch (version) {
+    case 18:
+      return std::string("macOS 10.14.x Mojave ") + info.machine;
     case 17:
       return std::string("macOS 10.13.x High Sierra ") + info.machine;
     case 16:
@@ -662,7 +666,7 @@ std::string get_local_hardware_info() {
 //----------------------------------------------------------------------------------------------------------------------
 
 std::int64_t get_physical_memory_size() {
-#if defined(__WIN__) || defined(_WIN32) || defined(_WIN64)
+#if defined(_MSC_VER)
   MEMORYSTATUS memstat;
 
   GlobalMemoryStatus(&memstat);
@@ -718,8 +722,6 @@ std::int64_t get_physical_memory_size() {
       }
     }
     fclose(proc);
-  } else {
-    g_warning("Memory stats retrieval not implemented for this system");
   }
   return mem64;
 
@@ -729,7 +731,7 @@ std::int64_t get_physical_memory_size() {
 //----------------------------------------------------------------------------------------------------------------------
 
 std::int64_t get_file_size(const char *filename) {
-#if _WIN32
+#if _MSC_VER
   DWORD dwSizeLow;
   DWORD dwSizeHigh = 0;
   HANDLE hfile;
@@ -823,7 +825,7 @@ const char *strfindword(const char *str, const char *word) {
  * @return 1 if the operation was successfull, otherwise 0.
  */
 int copy_file(const char *source, const char *target) {
-#ifdef _WIN32
+#ifdef _MSC_VER
   {
     const int cch_buf = MAX_PATH;
     WCHAR src_path[MAX_PATH];
@@ -888,7 +890,7 @@ int copy_folder(const char *source_folder, const char *target_folder) {
       char *source = g_build_filename(source_folder, entry, NULL);
       char *target = g_build_filename(target_folder, entry, NULL);
       if (!copy_file(source, target)) {
-        g_warning("Could not copy file %s to %s: %s", source, target, g_strerror(errno));
+        logWarning("Could not copy file %s to %s: %s\n", source, target, g_strerror(errno));
         g_free(source);
         g_free(target);
         g_dir_close(dir);
@@ -899,7 +901,7 @@ int copy_folder(const char *source_folder, const char *target_folder) {
     }
     g_dir_close(dir);
   } else {
-    g_warning("Could not open directory %s", source_folder);
+    logWarning("Could not open directory %s\n", source_folder);
     return 0;
   }
   return 1;
@@ -910,7 +912,7 @@ int copy_folder(const char *source_folder, const char *target_folder) {
 namespace base {
 
   double timestamp() {
-#if defined(__WIN__) || defined(_WIN32) || defined(_WIN64)
+#if defined(_MSC_VER)
     return (double)GetTickCount() / 1000.0;
 #else
     struct timeval tv;
@@ -925,7 +927,7 @@ namespace base {
 
   std::string fmttime(time_t t, const char *fmt) {
     char date[100];
-#ifdef _WIN32
+#ifdef _MSC_VER
     errno_t err;
 #else
     int err;
@@ -935,7 +937,7 @@ namespace base {
     if (t == 0)
       time(&t);
 
-#ifdef _WIN32
+#ifdef _MSC_VER
     err = localtime_s(&newtime, &t);
 #else
     localtime_r(&t, &newtime);
@@ -949,7 +951,14 @@ namespace base {
 
     return date;
   }
+  
 
+  BASELIBRARY_PUBLIC_FUNC std::string getVersion(void) {
+    return strfmt("%u.%u.%u", APP_MAJOR_NUMBER, APP_MINOR_NUMBER, APP_RELEASE_NUMBER);
+  }
+  
+  
 } // namespace base
 
 //--------------------------------------------------------------------------------------------------
+
