@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "driver_manager.h"
@@ -23,6 +27,7 @@
 #include "cppconn/driver.h"
 #include "cppconn/statement.h"
 #include "cppconn/exception.h"
+#include "cppconn/metadata.h"
 #include "base/string_utilities.h"
 
 #include <gmodule.h>
@@ -229,7 +234,7 @@ namespace sql {
     if (library == "mysqlcppconn")
       driver = get_driver_instance();
     else {
-#ifdef _WIN32
+#ifdef _MSC_VER
       library.append(".dll");
 #elif defined(__APPLE__)
       library.append(".dylib");
@@ -301,14 +306,14 @@ namespace sql {
     properties["CLIENT_MULTI_STATEMENTS"] = true;
     properties["metadataUseInfoSchema"] =
       false; // I_S is way too slow for many things as of MySQL 5.6.10, so disable it for now
-#if defined(__APPLE__) || defined(_WIN32)
+
     // set application name
     {
       std::map<sql::SQLString, sql::SQLString> attribs;
       attribs["program_name"] = "MySQLWorkbench";
       properties["OPT_CONNECT_ATTR_ADD"] = attribs;
     }
-#endif
+    
     // If SSL is enabled but there's no certificate or anything, create the sslKey option to force enabling SSL without
     // a key
     // (equivalent to starting cmdline client with mysql --ssl-key=)
@@ -330,6 +335,7 @@ namespace sql {
     {
       case 0:
          sslMode = sql::SSL_MODE_DISABLED;
+         properties["OPT_GET_SERVER_PUBLIC_KEY"] = true;
         break;
       case 1:
         sslMode = sql::SSL_MODE_PREFERRED;
@@ -349,7 +355,7 @@ namespace sql {
     // If we are on a pipe connection then set the host name explicitly.
     // However, pipe connections can only be established on the local box (Win only).
     if (drv->name() == "MysqlNativeSocket") {
-#ifdef _WIN32
+#ifdef _MSC_VER
       ConnectOptionsMap::iterator it = properties.find("socket");
       if (it != properties.end()) {
         properties["pipe"] = it->second;
@@ -456,6 +462,13 @@ namespace sql {
       if (connection_init_slot)
         connection_init_slot(conn.get(), connectionProperties);
 
+      //  We could set this on the parameters, but we wouldn't know the server version
+      if( conn->getMetaData()->getDatabaseMajorVersion() >= 8 ) {
+        conn.get()->createStatement()->executeUpdate("set character_set_client = utf8mb4");
+        conn.get()->createStatement()->executeUpdate("set character_set_connection = utf8mb4");
+        conn.get()->createStatement()->executeUpdate("set character_set_results = utf8mb4");
+      }
+      
       std::string def_schema = parameter_values.get_string("schema", "");
       if (!def_schema.empty())
         conn->setSchema(def_schema);
