@@ -1,20 +1,24 @@
-/* 
- * Copyright (c) 2008, 2016, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
+ *
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #import "MFFileChooser.h"
@@ -93,7 +97,7 @@
   [text setEditable: NO];
   [text setDrawsBackground: NO];
   [text setBordered: NO];
-  text.alignment = NSRightTextAlignment;
+  text.alignment = NSTextAlignmentRight;
   [mOptionsView addSubview: text];
   text.autoresizingMask = NSMinXEdge|NSMaxYEdge;
   [mOptionsView addSubview: pop];
@@ -161,7 +165,7 @@ static bool filechooser_run_modal(mforms::FileChooser *self)
     chooser->mPanel.message = @"";
     if (filename != nil)
       chooser->mPanel.nameFieldStringValue = filename;
-    if ([chooser->mPanel runModal] == NSFileHandlingPanelOKButton)
+    if ([chooser->mPanel runModal] == NSModalResponseOK)
       return true;
   }
   return false;
