@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #import "MFMForms.h"
@@ -32,19 +36,19 @@
 
 - (instancetype)initWithObject: (mforms::Form *)form owner: (mforms::Form *)ownerWindow flags: (mforms::FormFlag)formFlags {
 
-  NSUInteger styleMask = NSTitledWindowMask | NSClosableWindowMask;
+  NSUInteger styleMask = NSWindowStyleMaskTitled | NSWindowStyleMaskClosable;
 
   if ((formFlags & mforms::FormResizable) != 0)
-    styleMask |= NSResizableWindowMask;
+    styleMask |= NSWindowStyleMaskResizable;
 
   if ((formFlags & mforms::FormMinimizable) != 0)
-    styleMask |= NSMiniaturizableWindowMask;
+    styleMask |= NSWindowStyleMaskMiniaturizable;
 
   if ((formFlags & mforms::FormStayOnTop) != 0)
-    styleMask |= NSDocModalWindowMask;
+    styleMask |= NSWindowStyleMaskDocModalWindow;
 
   if ((formFlags & mforms::FormToolWindow) != 0)
-    styleMask |= NSUtilityWindowMask;
+    styleMask |= NSWindowStyleMaskUtilityWindow;
 
   self = [super
     initWithContentRect: NSMakeRect(100, 100, 100, 100)
