@@ -1,20 +1,24 @@
-/* 
- * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
+ *
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #import "MFImageBox.h"
@@ -30,7 +34,7 @@
   self= [super initWithFrame:NSMakeRect(10,10,10,10)];
   if (self)
   {
-    [self setImageFrameStyle: NSImageFrameNone];
+    self.imageFrameStyle = NSImageFrameNone;
     mOwner= aImage;
     mOwner->set_data(self);
     mScale= NO;
@@ -47,10 +51,14 @@
 
 - (NSSize)minimumSize
 {
+  NSSize minSize = super.minimumSize;
   if (!mScale)
-    return [[self image] size];
-  else
-    return [super minimumSize];
+    return { MAX(minSize.width, self.image.size.width), MAX(minSize.height, self.image.size.height) };
+  return minSize;
+}
+
+- (NSSize)preferredSize: (NSSize)proposal {
+  return [self minimumSize];
 }
 
 static bool imagebox_create(mforms::ImageBox *image)
@@ -64,14 +72,11 @@ static void imagebox_set_image(mforms::ImageBox *self, const std::string &file)
   if (self)
   {
     MFImageBoxImpl *impl= self->get_data();
-    NSSize oldSize= [impl frame].size;
-    
-    std::string full_path= mforms::App::get()->get_resource_path(file);
-    NSImage *image= [[NSImage alloc] initWithContentsOfFile: wrap_nsstring(full_path)];
-    [impl setImage: image];
 
-    if (!NSEqualSizes([image size], oldSize))
-      [[impl superview] subviewMinimumSizeChanged];
+    std::string full_path = mforms::App::get()->get_resource_path(file);
+    NSImage *image = [[NSImage alloc] initWithContentsOfFile: wrap_nsstring(full_path)];
+    impl.image = image;
+    impl.frameSize = image.size;
   }
 }
 
@@ -81,16 +86,16 @@ static void imagebox_set_image_data(mforms::ImageBox *self, const char *data, si
   if (self)
   {
     MFImageBoxImpl *impl= self->get_data();
-    NSSize oldSize= [impl frame].size;
+    NSSize oldSize= impl.frame.size;
     
     NSImage *image= [[NSImage alloc] initWithData: [NSData dataWithBytes: (void*)data length: length]];
-    if (![image isValid])
+    if (!image.valid)
       throw std::invalid_argument("Invalid image data");
 
-    [impl setImage: image];
+    impl.image = image;
     
-    if (!NSEqualSizes([image size], oldSize))
-      [[impl superview] subviewMinimumSizeChanged];
+    if (!NSEqualSizes(image.size, oldSize))
+      [impl.superview relayout];
   }
 }
 
@@ -102,35 +107,33 @@ static void imagebox_set_alignment(mforms::ImageBox *self, mforms::Alignment ali
     switch (alignment)
     {
       case mforms::BottomLeft:
-        [impl setImageAlignment: NSImageAlignBottomLeft];
+        impl.imageAlignment = NSImageAlignBottomLeft;
         break;
       case mforms::MiddleLeft:
-        [impl setImageAlignment: NSImageAlignLeft];
+        impl.imageAlignment = NSImageAlignLeft;
         break;
       case mforms::TopLeft:
-        [impl setImageAlignment: NSImageAlignTopLeft];
+        impl.imageAlignment = NSImageAlignTopLeft;
         break;
       case mforms::BottomCenter:
-        [impl setImageAlignment: NSImageAlignBottom];
+        impl.imageAlignment = NSImageAlignBottom;
         break;
       case mforms::TopCenter:
-        [impl setImageAlignment: NSImageAlignTop];
+        impl.imageAlignment = NSImageAlignTop;
         break;
       case mforms::MiddleCenter:
-        [impl setImageAlignment: NSImageAlignCenter];
+        impl.imageAlignment = NSImageAlignCenter;
         break;
       case mforms::BottomRight:
-        [impl setImageAlignment: NSImageAlignBottomRight];
+        impl.imageAlignment = NSImageAlignBottomRight;
         break;
       case mforms::MiddleRight:
-        [impl setImageAlignment: NSImageAlignRight];
+        impl.imageAlignment = NSImageAlignRight;
         break;
       case mforms::TopRight:
-        [impl setImageAlignment: NSImageAlignTopRight];
+        impl.imageAlignment = NSImageAlignTopRight;
         break;
-
       case mforms::NoAlign:
-      case mforms::WizardLabelAlignment:
         break;
     }
   }  
