@@ -1,20 +1,24 @@
-/* 
- * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
+ *
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #import "MFListBox.h"
@@ -55,14 +59,15 @@ STANDARD_FOCUS_HANDLING(self) // Notify backend when getting first responder sta
 
 - (instancetype)initWithObject:(::mforms::ListBox*)aListBox
 {
-  self= [super initWithFrame:NSMakeRect(0, 0, 40, 40)];
-  if (self)
+  self = [super initWithFrame:NSMakeRect(0, 0, 40, 40)];
+  if (self != nil)
   { 
     mOwner= aListBox;
     mOwner->set_data(self);
     
     [self setHasVerticalScroller:YES];
     [self setAutohidesScrollers:YES];
+    self.minimumSize = { 40, 50 };
 
     NSRect rect;
     rect.origin= NSMakePoint(0, 0);
@@ -70,49 +75,38 @@ STANDARD_FOCUS_HANDLING(self) // Notify backend when getting first responder sta
                              horizontalScrollerClass: nil
                                verticalScrollerClass: [NSScroller class]
                                           borderType: NSBezelBorder
-                                         controlSize: NSRegularControlSize
+                                         controlSize: NSControlSizeRegular
                                        scrollerStyle: NSScrollerStyleOverlay];
     mTable = [[DraggingTableView alloc] initWithFrame: rect owner: aListBox];
-    mHeader= [mTable headerView];
+    mHeader= mTable.headerView;
     [mTable setHeaderView: nil];
     [mTable setAllowsMultipleSelection: YES];
-    [self setBorderType: NSBezelBorder];
-    [self setDocumentView: mTable];
+    self.borderType = NSBezelBorder;
+    self.documentView = mTable;
     
     mContents= [NSMutableArray array];
     [mTable setDataSource: self];
     [mTable setDelegate: self];
-    [mTable setColumnAutoresizingStyle: NSTableViewLastColumnOnlyAutoresizingStyle];
+    mTable.columnAutoresizingStyle = NSTableViewLastColumnOnlyAutoresizingStyle;
     {
       NSTableColumn *column= [[NSTableColumn alloc] initWithIdentifier: @"0"];
     
       [mTable addTableColumn: column];
-      [column setResizingMask: NSTableColumnAutoresizingMask|NSTableColumnUserResizingMask];
-      //[column setResizable: YES];
-      [[column dataCell] setEditable:NO];
+      column.resizingMask = NSTableColumnAutoresizingMask|NSTableColumnUserResizingMask;
+      [column.dataCell setEditable:NO];
     }
   }
   return self;
 }
 
-
-
-
-- (void)setEnabled:(BOOL)flag
+- (void)setEnabled: (BOOL)flag
 {
-  [mTable setEnabled: flag];
+  mTable.enabled = flag;
 }
 
-
-- (NSSize)minimumSize
+- (NSInteger)numberOfRowsInTableView: (NSTableView *)aTableView
 {
-  return NSMakeSize(40, 50);
-}
-
-
-- (NSInteger)numberOfRowsInTableView:(NSTableView *)aTableView
-{
-  return [mContents count];
+  return mContents.count;
 }
 
 
@@ -127,14 +121,12 @@ STANDARD_FOCUS_HANDLING(self) // Notify backend when getting first responder sta
   mOwner->selection_changed();
 }
 
-// TODO: due to the mix of own tag definition and predefined tag values it is not clear if this
-//       is meant to really manipulate the table's tag value or addresses the now named viewFlags property.
-- (void)setViewFlags: (NSInteger)tag
+- (void)setViewFlags: (ViewFlags)flags
 {
-  mTable.viewFlags = tag;
+  mTable.viewFlags = ViewFlags(flags);
 }
 
-- (NSInteger)viewFlags
+- (ViewFlags)viewFlags
 {
   return mTable.viewFlags;
 }
@@ -143,7 +135,7 @@ STANDARD_FOCUS_HANDLING(self) // Notify backend when getting first responder sta
 - (void)resizeSubviewsWithOldSize:(NSSize)oldSize
 {
   [super resizeSubviewsWithOldSize: oldSize];
-  [[mTable tableColumnWithIdentifier: @"0"] setWidth: NSWidth([mTable frame])];
+  [mTable tableColumnWithIdentifier: @"0"].width = NSWidth(mTable.frame);
 }
 
 
@@ -196,7 +188,7 @@ static size_t listbox_add_item(::mforms::ListBox *self, const std::string &item)
     {
       [listbox->mContents addObject:wrap_nsstring(item)];
       [listbox->mTable reloadData];
-      return [listbox->mContents count]-1;
+      return listbox->mContents.count-1;
     }
   }
   return -1;
@@ -243,8 +235,8 @@ static std::string listbox_get_text(::mforms::ListBox *self)
     
     if ( listbox )
     {
-      if ([listbox->mTable selectedRow] >= 0)
-        return [listbox->mContents[[listbox->mTable selectedRow]] UTF8String];
+      if (listbox->mTable.selectedRow >= 0)
+        return [listbox->mContents[listbox->mTable.selectedRow] UTF8String];
     }
   }
   return "";
@@ -276,7 +268,7 @@ static ssize_t listbox_get_index(::mforms::ListBox *self)
     
     if ( listbox )
     {
-      return [listbox->mTable selectedRow];
+      return listbox->mTable.selectedRow;
     }
   }
   return -1;
@@ -290,7 +282,7 @@ static size_t listbox_get_count(::mforms::ListBox *self)
     
     if (listbox)
     {
-      return [listbox->mContents count];
+      return listbox->mContents.count;
     }
   }
   return 0;
@@ -304,7 +296,7 @@ static std::string listbox_get_string_value_from_index(::mforms::ListBox *self,
     
     if (listbox)
     {
-      if (index < [listbox->mContents count])
+      if (index < listbox->mContents.count)
         return [listbox->mContents[index] UTF8String];
     }
   }
@@ -321,8 +313,8 @@ static std::vector<size_t> listbox_get_selected_indices(::mforms::ListBox *self)
     
     if (listbox)
     {
-      NSIndexSet* indices = [listbox->mTable selectedRowIndexes];
-      NSUInteger index= [indices firstIndex];
+      NSIndexSet* indices = listbox->mTable.selectedRowIndexes;
+      NSUInteger index= indices.firstIndex;
       while (index != NSNotFound)
       {
         result.push_back(index);
@@ -342,10 +334,10 @@ static void listbox_set_heading(::mforms::ListBox *self, const std::string &text
     
     if (listbox->mHeader)
     {
-      [listbox->mTable setHeaderView:listbox->mHeader];
+      listbox->mTable.headerView = listbox->mHeader;
       listbox->mHeader= nil;
     }
-    [[[[listbox->mTable tableColumns] lastObject] headerCell] setStringValue: wrap_nsstring(text)];
+    listbox->mTable.tableColumns.lastObject.headerCell.stringValue = wrap_nsstring(text);
   }
 }
 
