@@ -1,20 +1,24 @@
-/* 
- * Copyright (c) 2010, 2016, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2010, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
+ *
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #import "MFMenu.h"
@@ -35,7 +39,7 @@
 
   NSPopUpButtonCell* popUpButtonCell = [[NSPopUpButtonCell alloc] initTextCell: @""
                                                                      pullsDown: pullsDown];
-  [popUpButtonCell setMenu: popup];
+  popUpButtonCell.menu = popup;
   if (!pullsDown)
     [popUpButtonCell selectItem: nil];
   [popUpButtonCell performClickWithFrame: frame inView: view];
@@ -62,8 +66,8 @@
 
 - (void) handleCommand: (NSMenuItem*) sender
 {
-  NSString* command = [sender representedObject];
-  mOwner->handle_action([command UTF8String]);
+  NSString* command = sender.representedObject;
+  mOwner->handle_action(command.UTF8String);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -91,14 +95,14 @@ static int menu_add_item(mforms::Menu *self, const std::string &caption, const s
   NSMenuItem* item;
   
   item = [[NSMenuItem alloc] init];
-  [item setRepresentedObject: @(action.c_str())];
-  [item setTarget: menu];
-  [item setAction: @selector(handleCommand:)];
-  [item setTitle: @(caption.c_str())];
-  [item setEnabled: true];
+  item.representedObject = @(action.c_str());
+  item.target = menu;
+  item.action = @selector(handleCommand:);
+  item.title = @(caption.c_str());
+  item.enabled = true;
   
   [menu addItem: item];
-  return [menu numberOfItems] - 1;
+  return (int)menu.numberOfItems - 1;
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -110,7 +114,7 @@ static int menu_add_separator(mforms::Menu *self)
   NSMenuItem* item;
   item = [NSMenuItem separatorItem];
   [menu addItem: item];
-  return [menu numberOfItems] - 1;
+  return (int)menu.numberOfItems - 1;
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -121,13 +125,13 @@ static int menu_add_submenu(mforms::Menu *self, const std::string &caption, mfor
   
   NSMenuItem* item;
   item = [[NSMenuItem alloc] init];
-  [item setTitle: @(caption.c_str())];
-  [item setEnabled: true];
+  item.title = @(caption.c_str());
+  item.enabled = true;
 
   [menu addItem: item];
   MFMenuImpl* theSubMenu = submenu->get_data();
   [menu setSubmenu: theSubMenu forItem: item];
-  return [menu numberOfItems] - 1;
+  return (int)menu.numberOfItems - 1;
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -136,7 +140,7 @@ static void menu_set_item_enabled(mforms::Menu *self, int i, bool flag)
 {
   MFMenuImpl* menu = self->get_data();
   
-  [[menu itemAtIndex: i] setEnabled: flag];
+  [menu itemAtIndex: i].enabled = flag;
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -178,7 +182,7 @@ static void menu_clear(mforms::Menu *self)
   MFMenuImpl* menu = self->get_data();
   
   // [menu removeAllItems]; available on 10.6+
-  while ([menu numberOfItems] > 0)
+  while (menu.numberOfItems > 0)
     [menu removeItemAtIndex: 0];
 }
 
