@@ -1,20 +1,24 @@
-/* 
- * Copyright (c) 2011, 2015, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
+ *
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #import "MFPopover.h"
@@ -22,14 +26,13 @@
 
 //--------------------------------------------------------------------------------------------------
 
-@interface PopoverFrameView : NSView
-{
+@interface PopoverFrameView : NSView {
   NSBezierPath* outline;
-  @public
+@public
   BOOL readOnly;
 }
 
-@property (nonatomic, strong) NSBezierPath* outline;
+@property(nonatomic, strong) NSBezierPath* outline;
 
 @end
 
@@ -39,22 +42,13 @@
 
 @synthesize outline;
 
-- (void)drawRect: (NSRect)rect
-{
-  NSGraphicsContext *context = [NSGraphicsContext currentContext];
+- (void)drawRect: (NSRect)rect {
+  NSGraphicsContext* context = [NSGraphicsContext currentContext];
   [context saveGraphicsState];
 
-  if (readOnly)
-    [[NSColor colorWithDeviceRed: 248/255.0 green: 245/255.0 blue: 198/255.0  alpha: 1] set];
-  else
-    [[NSColor colorWithDeviceWhite: 232 / 255.0 alpha: 1] set];
-
+  [NSColor.windowBackgroundColor set];
   [outline fill];
-	
-  // Something is drawing the border for us. Can't find out which part does it, though.
-  //[[NSColor colorWithDeviceWhite: 118 / 255.0 alpha: 1] set];
-	//[outline stroke];
-  
+
   [context restoreGraphicsState];
 }
 
@@ -65,22 +59,16 @@
 @implementation MFPopover
 
 - (instancetype)initWithContentRect: (NSRect)contentRect
-                styleMask: (NSUInteger)windowStyle
-                  backing: (NSBackingStoreType)bufferingType
-                    defer: (BOOL)deferCreation
-                    style: (mforms::PopoverStyle)style
-{
-  self = [super initWithContentRect: contentRect
-                          styleMask: windowStyle
-                            backing: bufferingType
-                              defer: deferCreation];
-  if (self)
-  {
-    PopoverFrameView* frameView = [super contentView];
+                          styleMask: (NSUInteger)windowStyle
+                            backing: (NSBackingStoreType)bufferingType
+                              defer: (BOOL)deferCreation
+                              style: (mforms::PopoverStyle)style {
+  self = [super initWithContentRect:contentRect styleMask: windowStyle backing: bufferingType defer: deferCreation];
+  if (self) {
+    PopoverFrameView* frameView = super.contentView;
     frameView->readOnly = style == mforms::PopoverStyleTooltip;
     mStyle = style;
-    switch (mStyle)
-    {
+    switch (mStyle) {
       case mforms::PopoverStyleTooltip:
         mArrowSize = 8;
         mArrowBase = 16;
@@ -90,25 +78,22 @@
       default:
         mArrowSize = 16;
         mArrowBase = 32;
-        mCornerRadius = 14;
+        mCornerRadius = 10;
         break;
     }
-    [self setOpaque: NO];
-    [self setBackgroundColor: [NSColor clearColor]];
+    [self setOpaque:NO];
+    self.backgroundColor = [NSColor clearColor];
   }
   return self;
 }
 
-
-- (void)dealloc
-{
+- (void)dealloc {
   [NSObject cancelPreviousPerformRequestsWithTarget: self];
 }
 
 //--------------------------------------------------------------------------------------------------
 
-- (BOOL)canBecomeKeyWindow
-{
+- (BOOL)canBecomeKeyWindow {
   return YES;
 }
 
@@ -117,17 +102,16 @@
 /**
  * Resize the frame view to accomodate the content view.
  */
-- (void)setContentSize: (NSSize)newSize
-{
+- (void)setContentSize: (NSSize)newSize {
   mBaseSize = newSize;
 
   NSSize sizeDelta = newSize;
-  NSSize childBoundsSize = [mChildContentView bounds].size;
+  NSSize childBoundsSize = mChildContentView.bounds.size;
   sizeDelta.width -= childBoundsSize.width;
   sizeDelta.height -= childBoundsSize.height;
 
-  PopoverFrameView* frameView = [super contentView];
-  NSSize newFrameSize = [frameView bounds].size;
+  PopoverFrameView* frameView = super.contentView;
+  NSSize newFrameSize = frameView.bounds.size;
   newFrameSize.width += sizeDelta.width;
   newFrameSize.height += sizeDelta.height;
 
@@ -139,35 +123,32 @@
 /**
  * Set the given view as content view, that is, as child of our frame view.
  */
-- (void)setContentView: (NSView *)aView
-{
+- (void)setContentView: (NSView*)aView {
   if ([mChildContentView isEqualTo: aView])
     return;
 
-  NSRect bounds = [self frame];
+  NSRect bounds = self.frame;
   bounds.origin = NSZeroPoint;
 
-  PopoverFrameView* frameView = [super contentView];
-  if (!frameView)
-  {
+  PopoverFrameView* frameView = super.contentView;
+  if (!frameView) {
     frameView = [[PopoverFrameView alloc] initWithFrame: bounds];
     frameView->readOnly = mStyle == mforms::PopoverStyleTooltip;
-    [super setContentView: frameView];
+    super.contentView = frameView;
   }
 
   if (mChildContentView != nil)
     [mChildContentView removeFromSuperview];
 
   mChildContentView = aView; // No retain required here, the frame view controls the lifetime.
-  [mChildContentView setFrame: [self contentRectForFrameRect: bounds]];
-  [mChildContentView setAutoresizingMask: NSViewWidthSizable | NSViewHeightSizable];
-  [frameView addSubview: mChildContentView];
+  mChildContentView.frame = [self contentRectForFrameRect: bounds];
+  mChildContentView.autoresizingMask = NSViewWidthSizable | NSViewHeightSizable;
+  [frameView addSubview:mChildContentView];
 }
 
 //--------------------------------------------------------------------------------------------------
 
-- (NSView *)contentView
-{
+- (NSView*)contentView {
   return mChildContentView;
 }
 
@@ -175,16 +156,14 @@
 
 #define DEFAULT_PADDING 7 // Padding on all sides.
 
-- (NSRect)contentRectForFrameRect:(NSRect)windowFrame
-{
+- (NSRect)contentRectForFrameRect: (NSRect)windowFrame {
   return NSMakeRect(windowFrame.origin.x + mPadding.left, windowFrame.origin.y + mPadding.bottom,
                     windowFrame.size.width - mPadding.horizontal(), windowFrame.size.height - mPadding.vertical());
 }
 
 //--------------------------------------------------------------------------------------------------
 
-- (void)computeCoordinatesAndPadding: (mforms::StartPosition) position
-{
+- (void)computeCoordinatesAndPadding: (mforms::StartPosition)position {
   // The base size is the size of the main part, without arrow.
   NSSize actualSize = mBaseSize;
   actualSize.width += 2 * DEFAULT_PADDING;
@@ -200,43 +179,38 @@
   // for a more appealing look. Additionally, add the arrow's size to the padding on this size to
   // exclude its area from the main content area.
   NSPoint newLocation;
-  switch (position)
-  {
+  switch (position) {
     case mforms::StartLeft:
       newLocation.x = mHotSpot.x - actualSize.width;
       newLocation.y = mHotSpot.y - actualSize.height / 3;
-      mPadding = base::Padding(DEFAULT_PADDING, DEFAULT_PADDING,
-                                          DEFAULT_PADDING + mArrowSize, DEFAULT_PADDING);
+      mPadding = base::Padding(DEFAULT_PADDING, DEFAULT_PADDING, DEFAULT_PADDING + mArrowSize, DEFAULT_PADDING);
       break;
     case mforms::StartRight:
       newLocation.x = mHotSpot.x;
       newLocation.y = mHotSpot.y - actualSize.height / 3;
-      mPadding = base::Padding(DEFAULT_PADDING + mArrowSize, DEFAULT_PADDING,
-                                          DEFAULT_PADDING, DEFAULT_PADDING);
+      mPadding = base::Padding(DEFAULT_PADDING + mArrowSize, DEFAULT_PADDING, DEFAULT_PADDING, DEFAULT_PADDING);
       break;
     case mforms::StartAbove:
       newLocation.x = mHotSpot.x - actualSize.width / 3;
       newLocation.y = mHotSpot.y;
-      mPadding = base::Padding(DEFAULT_PADDING, DEFAULT_PADDING,
-                                          DEFAULT_PADDING, DEFAULT_PADDING + mArrowSize);
+      mPadding = base::Padding(DEFAULT_PADDING, DEFAULT_PADDING, DEFAULT_PADDING, DEFAULT_PADDING + mArrowSize);
       break;
     case mforms::StartBelow:
       newLocation.x = mHotSpot.x - actualSize.width / 3;
       newLocation.y = mHotSpot.y - actualSize.height;
-      mPadding = base::Padding(DEFAULT_PADDING, DEFAULT_PADDING + mArrowSize,
-                                          DEFAULT_PADDING, DEFAULT_PADDING);
+      mPadding = base::Padding(DEFAULT_PADDING, DEFAULT_PADDING + mArrowSize, DEFAULT_PADDING, DEFAULT_PADDING);
       break;
   }
 
   NSScreen* currentScreen = [NSScreen mainScreen];
-  NSRect screenBounds = [currentScreen visibleFrame];
+  NSRect screenBounds = currentScreen.visibleFrame;
 
   // Check the control's bounds and determine the amount of pixels we have to move it make
   // it fully appear on screen. This will usually not move the hot spot, unless the movement
   // of the control is so much that it would leave the arrow outside its bounds.
   int deltaX = 0;
   int deltaY = 0;
-  NSRect frame = [self frame];
+  NSRect frame = self.frame;
   if (newLocation.x < screenBounds.origin.x)
     deltaX = screenBounds.origin.x - newLocation.x;
   if (newLocation.x + frame.size.width > NSMaxX(screenBounds))
@@ -250,115 +224,108 @@
   newLocation.y += deltaY;
 
   // Now that we have the final location check the arrow again.
-  switch (position)
-  {
-  case mforms::StartLeft:
-  case mforms::StartRight:
-    mHotSpot.x += deltaX;
-    if ((mHotSpot.y - mArrowBase / 2) < (newLocation.y + mCornerRadius))
-      mHotSpot.y = newLocation.y + mCornerRadius + mArrowBase / 2;
-    if ((mHotSpot.y + mArrowBase / 2) > (newLocation.y + actualSize.height - mCornerRadius))
-      mHotSpot.y = newLocation.y + actualSize.height - mCornerRadius - mArrowBase / 2;
-    break;
-  case mforms::StartAbove:
-  case mforms::StartBelow:
-    if ((mHotSpot.x - mArrowBase / 2) < (newLocation.x + mCornerRadius))
-      mHotSpot.x = newLocation.x + mCornerRadius + mArrowBase / 2;
-    if ((mHotSpot.x + mArrowBase / 2) > (newLocation.x + actualSize.width - mCornerRadius))
-      mHotSpot.x = newLocation.x + actualSize.width - mCornerRadius - mArrowBase / 2;
-    mHotSpot.y += deltaY;
-    break;
+  switch (position) {
+    case mforms::StartLeft:
+    case mforms::StartRight:
+      mHotSpot.x += deltaX;
+      if ((mHotSpot.y - mArrowBase / 2) < (newLocation.y + mCornerRadius))
+        mHotSpot.y = newLocation.y + mCornerRadius + mArrowBase / 2;
+      if ((mHotSpot.y + mArrowBase / 2) > (newLocation.y + actualSize.height - mCornerRadius))
+        mHotSpot.y = newLocation.y + actualSize.height - mCornerRadius - mArrowBase / 2;
+      break;
+    case mforms::StartAbove:
+    case mforms::StartBelow:
+      if ((mHotSpot.x - mArrowBase / 2) < (newLocation.x + mCornerRadius))
+        mHotSpot.x = newLocation.x + mCornerRadius + mArrowBase / 2;
+      if ((mHotSpot.x + mArrowBase / 2) > (newLocation.x + actualSize.width - mCornerRadius))
+        mHotSpot.x = newLocation.x + actualSize.width - mCornerRadius - mArrowBase / 2;
+      mHotSpot.y += deltaY;
+      break;
   }
 
-  [self setFrameOrigin: newLocation];
+  [self setFrameOrigin:newLocation];
 }
 
 //--------------------------------------------------------------------------------------------------
 
-- (void)computeOutline
-{
-  PopoverFrameView* frameView = [super contentView];
-  
-  NSRect bounds = [frameView bounds];
+- (void)computeOutline {
+  PopoverFrameView* frameView = super.contentView;
+
+  NSRect bounds = frameView.bounds;
   NSPoint localHotSpot = [self convertRectFromScreen: NSMakeRect(mHotSpot.x, mHotSpot.y, 0, 0)].origin;
   localHotSpot.x += 0.5;
 
   // The path is constructed counterclockwise.
   NSBezierPath* outline = [NSBezierPath bezierPath];
-  [outline setLineWidth: 1];
-  
+  outline.lineWidth = 1;
+
   CGFloat leftOffset = 0;
   CGFloat topOffset = 0;
   CGFloat rightOffset = 0;
   CGFloat bottomOffset = 0;
 
-  switch (mRelativePosition)
-  {
-    case mforms::StartLeft:
-    {
+  switch (mRelativePosition) {
+    case mforms::StartLeft: {
       rightOffset = mArrowSize;
       break;
     }
-    case mforms::StartRight:
-    {
+    case mforms::StartRight: {
       leftOffset = mArrowSize;
       break;
     }
-    case mforms::StartAbove:
-    {
+    case mforms::StartAbove: {
       bottomOffset = mArrowSize;
       break;
     }
-    case mforms::StartBelow:
-    {
+    case mforms::StartBelow: {
       topOffset = mArrowSize;
       break;
     }
   }
 
   // Left-bottom corner.
-  [outline appendBezierPathWithArcWithCenter: NSMakePoint(NSMinX(bounds) + mCornerRadius + leftOffset, NSMinY(bounds) + mCornerRadius + bottomOffset)
+  [outline appendBezierPathWithArcWithCenter: NSMakePoint(NSMinX(bounds) + mCornerRadius + leftOffset,
+                                                          NSMinY(bounds) + mCornerRadius + bottomOffset)
                                       radius: mCornerRadius
                                   startAngle: 180
                                     endAngle: -90];
-  if (bottomOffset > 0)
-  {
-    [outline lineToPoint: NSMakePoint(localHotSpot.x - mArrowBase / 2, NSMinY(bounds) + bottomOffset)];
-    [outline lineToPoint: NSMakePoint(localHotSpot.x, localHotSpot.y)];
-    [outline lineToPoint: NSMakePoint(localHotSpot.x + mArrowBase / 2, NSMinY(bounds) + bottomOffset)];
+  if (bottomOffset > 0) {
+    [outline lineToPoint:NSMakePoint(localHotSpot.x - mArrowBase / 2, NSMinY(bounds) + bottomOffset)];
+    [outline lineToPoint:NSMakePoint(localHotSpot.x, localHotSpot.y)];
+    [outline lineToPoint:NSMakePoint(localHotSpot.x + mArrowBase / 2, NSMinY(bounds) + bottomOffset)];
   }
 
   // Right-bottom corner.
-  [outline appendBezierPathWithArcWithCenter: NSMakePoint(NSMaxX(bounds) - mCornerRadius - rightOffset, NSMinY(bounds) + mCornerRadius + bottomOffset)
+  [outline appendBezierPathWithArcWithCenter: NSMakePoint(NSMaxX(bounds) - mCornerRadius - rightOffset,
+                                                          NSMinY(bounds) + mCornerRadius + bottomOffset)
                                       radius: mCornerRadius
-                                  startAngle: -90
+                                  startAngle:- 90
                                     endAngle: 0];
-  if (rightOffset > 0)
-  {
-    [outline lineToPoint: NSMakePoint(NSMaxX(bounds) - rightOffset, localHotSpot.y - mArrowBase / 2)];
-    [outline lineToPoint: localHotSpot];
-    [outline lineToPoint: NSMakePoint(NSMaxX(bounds) - rightOffset, localHotSpot.y + mArrowBase / 2)];
+  if (rightOffset > 0) {
+    [outline lineToPoint:NSMakePoint(NSMaxX(bounds) - rightOffset, localHotSpot.y - mArrowBase / 2)];
+    [outline lineToPoint:localHotSpot];
+    [outline lineToPoint:NSMakePoint(NSMaxX(bounds) - rightOffset, localHotSpot.y + mArrowBase / 2)];
   }
 
   // Right-top corner.
-  [outline appendBezierPathWithArcWithCenter: NSMakePoint(NSMaxX(bounds) - mCornerRadius - rightOffset, NSMaxY(bounds) - mCornerRadius - topOffset)
+  [outline appendBezierPathWithArcWithCenter: NSMakePoint(NSMaxX(bounds) - mCornerRadius - rightOffset,
+                                                          NSMaxY(bounds) - mCornerRadius - topOffset)
                                       radius: mCornerRadius
                                   startAngle: 0
                                     endAngle: 90];
-  if (topOffset > 0)
-  {
-    [outline lineToPoint: NSMakePoint(localHotSpot.x + mArrowBase / 2, NSMaxY(bounds) - topOffset)];
-    [outline lineToPoint: localHotSpot];
-    [outline lineToPoint: NSMakePoint(localHotSpot.x - mArrowBase / 2, NSMaxY(bounds) - topOffset)];
+  if (topOffset > 0) {
+    [outline lineToPoint:NSMakePoint(localHotSpot.x + mArrowBase / 2, NSMaxY(bounds) - topOffset)];
+    [outline lineToPoint:localHotSpot];
+    [outline lineToPoint:NSMakePoint(localHotSpot.x - mArrowBase / 2, NSMaxY(bounds) - topOffset)];
   }
 
   // Left-top corner.
-  [outline appendBezierPathWithArcWithCenter: NSMakePoint(NSMinX(bounds) + mCornerRadius + leftOffset, NSMaxY(bounds) - mCornerRadius - topOffset)
+  [outline appendBezierPathWithArcWithCenter: NSMakePoint(NSMinX(bounds) + mCornerRadius + leftOffset,
+                                                          NSMaxY(bounds) - mCornerRadius - topOffset)
                                       radius: mCornerRadius
                                   startAngle: 90
                                     endAngle: 180];
-  if (leftOffset > 0)
-  {
+  if (leftOffset > 0) {
     [outline lineToPoint: NSMakePoint(NSMinX(bounds) + leftOffset, localHotSpot.y + mArrowBase / 2)];
     [outline lineToPoint: localHotSpot];
     [outline lineToPoint: NSMakePoint(NSMinX(bounds) + leftOffset, localHotSpot.y - mArrowBase / 2)];
@@ -374,41 +341,35 @@
  * Resizes the window to accomodate the content view with the computed padding on each side
  * and then places the content view to the right position.
  */
-- (void)adjustWindowSizeAndContentFrame
-{
-  NSPoint origin = [self frame].origin;
-  NSRect newWindowFrame = NSMakeRect(origin.x,
-                                     origin.y,
-                                     mBaseSize.width + mPadding.horizontal(),
-                                     mBaseSize.height + mPadding.vertical());
+- (void)adjustWindowSizeAndContentFrame {
+  NSPoint origin = self.frame.origin;
+  NSRect newWindowFrame =
+    NSMakeRect(origin.x, origin.y, mBaseSize.width + mPadding.horizontal(), mBaseSize.height + mPadding.vertical());
 
-  [self setFrame: newWindowFrame display: NO animate: [self isVisible]];
-  [mChildContentView setFrame: NSMakeRect(mPadding.left, mPadding.bottom, mBaseSize.width, mBaseSize.height)];
+  [self setFrame: newWindowFrame display: NO animate: self.visible];
+  mChildContentView.frame = NSMakeRect(mPadding.left, mPadding.bottom, mBaseSize.width, mBaseSize.height);
 }
 
 //--------------------------------------------------------------------------------------------------
 
-- (void)show: (NSPoint)location relativePosition: (mforms::StartPosition)position
-{
+- (void)show:(NSPoint)location relativePosition: (mforms::StartPosition)position {
   if (location.x < 0 && location.y < 0)
     location = [NSEvent mouseLocation];
 
   mHotSpot = location;
   [self computeCoordinatesAndPadding: position];
-  if (![self isVisible] || mRelativePosition != position)
-  {
+  if (!(self.occlusionState & NSWindowOcclusionStateVisible) || mRelativePosition != position) {
     mRelativePosition = position;
     [self adjustWindowSizeAndContentFrame];
     [self computeOutline];
   }
 
-  if (![self isVisible])
-  {
+  if (!(self.occlusionState & NSWindowOcclusionStateVisible)) {
     [NSAnimationContext beginGrouping];
-    [self setAlphaValue: 0];
-    [self orderFront: nil];
-    [[NSAnimationContext currentContext] setDuration: 0.25];
-    [[self animator] setAlphaValue: 1];
+    self.alphaValue = 0;
+    [self orderFront:nil];
+    [NSAnimationContext currentContext].duration = 0.25;
+    [self animator].alphaValue = 1;
     [NSAnimationContext endGrouping];
   }
 }
@@ -416,37 +377,34 @@
 //--------------------------------------------------------------------------------------------------
 // Tracking area related
 
-- (void)mouseExited:(NSEvent *)theEvent
-{
-  if ([theEvent userData])
-  {
+- (void)mouseExited:(NSEvent*)theEvent {
+  if (theEvent.userData) {
     (*mOwner->signal_close())();
-  }
-  else
+  } else
     [super mouseExited: theEvent];
 }
 
 //--------------------------------------------------------------------------------------------------
 
-- (void)close
-{
+- (void)close {
   [mTrackedView removeTrackingArea: mOwnerTracking];
   mOwnerTracking = nil;
   mTrackedView = nil;
-  [[NSAnimationContext currentContext] setDuration: 0.25];
-  [[self animator] setAlphaValue: 0];
-  [self performSelector: @selector(orderOut:) withObject: nil afterDelay: 0.5
-                inModes: @[NSModalPanelRunLoopMode, NSDefaultRunLoopMode]];
+  [NSAnimationContext currentContext].duration = 0.25;
+  [self animator].alphaValue = 0;
+  [self performSelector: @selector(orderOut:)
+             withObject: nil
+             afterDelay: 0.5
+                inModes: @[ NSModalPanelRunLoopMode, NSDefaultRunLoopMode ]];
 }
 
 //--------------------------------------------------------------------------------------------------
 
 using namespace mforms;
 
-static bool popover_create(Popover* popover, mforms::PopoverStyle style)
-{
+static bool popover_create(Popover* popover, mforms::View *owner, mforms::PopoverStyle style) {
   MFPopover* popoverWindow = [[MFPopover alloc] initWithContentRect: NSMakeRect(0, 0, 100, 100)
-                                                          styleMask: NSBorderlessWindowMask
+                                                          styleMask: NSWindowStyleMaskBorderless
                                                             backing: NSBackingStoreBuffered
                                                               defer: NO
                                                               style: style];
@@ -460,59 +418,60 @@ static bool popover_create(Popover* popover, mforms::PopoverStyle style)
 
 //--------------------------------------------------------------------------------------------------
 
-static void popover_set_content(Popover* popover, View* content)
-{
-  [popover->get_data() setContentView: content->get_data()];
+static void popover_set_content(Popover* popover, View* content) {
+  [popover->get_data() setContentView:content->get_data()];
 }
 
 //--------------------------------------------------------------------------------------------------
 
-static void popover_set_size(Popover* popover, int width, int height)
-{
+static void popover_set_size(Popover* popover, int width, int height) {
   [popover->get_data() setContentSize: NSMakeSize(width, height)];
 }
 
 //--------------------------------------------------------------------------------------------------
 
-static void popover_show(Popover* popover, int x, int y, StartPosition relativePosition)
-{
-  [popover->get_data() show: NSMakePoint(x, y) relativePosition: relativePosition];
+static void popover_show(Popover* popover, int x, int y, StartPosition relativePosition) {
+  [popover->get_data() show: NSMakePoint(x, y) relativePosition:relativePosition];
 }
 
 //--------------------------------------------------------------------------------------------------
 
-static void popover_show_and_track(Popover* popover, View *owner, int x, int y, StartPosition relativePosition)
-{
-  MFPopover *impl = popover->get_data();
-  [impl show: NSMakePoint(x, y) relativePosition: relativePosition];
-  NSTrackingArea *tarea = [[NSTrackingArea alloc] initWithRect: [owner->get_data() bounds]
-                                                       options: NSTrackingMouseEnteredAndExited|NSTrackingAssumeInside|NSTrackingActiveAlways
-                                                         owner: popover->get_data()
-                                                      userInfo: @{}];
-  [owner->get_data() addTrackingArea: tarea];
+static void popover_show_and_track(Popover* popover, View* owner, int x, int y, StartPosition relativePosition) {
+  MFPopover* impl = popover->get_data();
+  [impl show:NSMakePoint(x, y) relativePosition:relativePosition];
+  NSTrackingArea* tarea = [[NSTrackingArea alloc]
+    initWithRect: [owner->get_data() bounds]
+         options: NSTrackingMouseEnteredAndExited | NSTrackingAssumeInside | NSTrackingActiveAlways
+           owner: popover->get_data()
+        userInfo: @{}];
+  [owner->get_data() addTrackingArea:tarea];
   impl->mTrackedView = owner->get_data();
   impl->mOwnerTracking = tarea;
 }
 
 //--------------------------------------------------------------------------------------------------
 
-static void popover_close(Popover* popover)
-{
+static void popover_close(Popover* popover) {
   [popover->get_data() close];
 }
 
 //--------------------------------------------------------------------------------------------------
 
-static void popover_destroy(Popover* popover)
-{
+static void popover_setName(Popover *popover, const std::string &name) {
+  MFPopover *native = popover->get_data();
+  native.accessibilityTitle = [NSString stringWithUTF8String: name.c_str()];
+}
+
+//--------------------------------------------------------------------------------------------------
+
+static void popover_destroy(Popover* popover) {
   popover->set_data(nil); // this will release the existing reference
 }
 
 //--------------------------------------------------------------------------------------------------
 
-void cf_popover_init()
-{
-  ::mforms::ControlFactory *f = ::mforms::ControlFactory::get_instance();
+void cf_popover_init() {
+  ::mforms::ControlFactory* f = ::mforms::ControlFactory::get_instance();
 
   f->_popover_impl.create = &popover_create;
   f->_popover_impl.destroy = &popover_destroy;
@@ -520,8 +479,8 @@ void cf_popover_init()
   f->_popover_impl.set_size = &popover_set_size;
   f->_popover_impl.show = &popover_show;
   f->_popover_impl.show_and_track = &popover_show_and_track;
-
-  f->_popover_impl.close= &popover_close;
+  f->_popover_impl.setName = &popover_setName;
+  f->_popover_impl.close = &popover_close;
 }
 
 @end
