@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2015, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2015, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include <set>
@@ -22,8 +26,17 @@
 #include <cctype>
 #include <future>
 
+#ifdef __APPLE__
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wcomma"
+#endif
+
 #include <boost/date_time.hpp>
 
+#ifdef __APPLE__
+#pragma GCC diagnostic pop
+#endif
+
 #include "mforms/jsonview.h"
 #include "mforms/panel.h"
 #include "mforms/treeview.h"
@@ -343,19 +356,22 @@ void JsonTreeBaseView::prepareMenu() {
         showAddModify = false;
 
       auto *item = mforms::manage(new mforms::MenuItem("Add new value"));
-      item->set_name("add_new_doc");
-      item->signal_clicked()->connect(std::bind(&JsonTreeBaseView::handleMenuCommand, this, item->get_name()));
+      item->set_name("Add New Document");
+      item->setInternalName("add_new_doc");
+      item->signal_clicked()->connect(std::bind(&JsonTreeBaseView::handleMenuCommand, this, item->getInternalName()));
       item->set_enabled(showAddModify);
       _contextMenu->add_item(item);
 
       item = mforms::manage(new mforms::MenuItem("Delete JSON"));
-      item->set_name("delete_doc");
-      item->signal_clicked()->connect(std::bind(&JsonTreeBaseView::handleMenuCommand, this, item->get_name()));
+      item->set_name("Delete Document");
+      item->setInternalName("delete_doc");
+      item->signal_clicked()->connect(std::bind(&JsonTreeBaseView::handleMenuCommand, this, item->getInternalName()));
       _contextMenu->add_item(item);
 
       item = mforms::manage(new mforms::MenuItem("Modify JSON"));
-      item->set_name("modify_doc");
-      item->signal_clicked()->connect(std::bind(&JsonTreeBaseView::handleMenuCommand, this, item->get_name()));
+      item->set_name("Modify Document");
+      item->setInternalName("modify_doc");
+      item->signal_clicked()->connect(std::bind(&JsonTreeBaseView::handleMenuCommand, this, item->getInternalName()));
       item->set_enabled(showAddModify);
       _contextMenu->add_item(item);
     }
@@ -1248,7 +1264,7 @@ void JsonGridView::addColumn(int size, JsonParser::DataType type, const std::str
     case VString:
     case VEmpty:
     default:
-      _treeView->add_column(StringColumnType, name, size, true, true);
+      _treeView->add_column(IconStringColumnType, name, size, true, true);
       break;
   }
 }
@@ -1647,7 +1663,7 @@ void JsonGridView::setStringData(int columnId, TreeNodeRef node, const std::stri
 
 void JsonTabView::Setup() {
   assert(_tabView != NULL);
-  _tabView->set_name("json_editor:tab");
+  _tabView->set_name("JSON Editor");
   _tabId.textTabId = _tabView->add_page(_textView, "Text");
   _tabId.treeViewTabId = _tabView->add_page(_treeView, "Tree");
   _tabId.gridViewTabId = _tabView->add_page(_gridView, "Grid");
