@@ -1,32 +1,35 @@
 /*
- * Copyright (c) 2010, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #pragma once
 
-#ifndef SCI_NAMESPACE
-#define SCI_NAMESPACE
-#endif
+#include <libxml/tree.h>
 #include "Scintilla.h"
 
-#include <mforms/view.h>
-#include <mforms/utilities.h>
-#include <libxml/tree.h>
+#include "base/notifications.h"
+
+#include "mforms/view.h"
+#include "mforms/utilities.h"
 
 /**
  * Provides a code editor with syntax highlighting for mforms.
@@ -43,11 +46,9 @@ namespace mforms {
 
   enum SyntaxHighlighterLanguage {
     LanguageNone,
-    LanguageMySQL50,
-    LanguageMySQL51,
-    LanguageMySQL55,
     LanguageMySQL56,
     LanguageMySQL57,
+    LanguageMySQL80,
 
     LanguageHtml, // includes embedded xml, javascript, php, vb, python
     LanguagePython,
@@ -55,11 +56,11 @@ namespace mforms {
     LanguageJS,
     LanguageJson,
 
-    LanguageMySQL = LanguageMySQL56, // Always the latest (released) language.
+    LanguageMySQL = LanguageMySQL80, // Always the latest (released) language.
   };
 
   /**
-   * A number of flags used to specify additional markup for a line (usually shown in the gutter).
+   * A number of flags used to specify additional markup for a line (shown in the gutter).
    */
   enum LineMarkup {
     LineMarkupNone = 0,               // No markup for the given line.
@@ -68,7 +69,7 @@ namespace mforms {
     LineMarkupBreakpoint = 1 << 2,    // Line has a marker set for a break point.
     LineMarkupBreakpointHit = 1 << 3, // Line has a marker set for a break point which is currently hit.
     LineMarkupCurrent = 1 << 4,       // Current execution line.
-    LineMarkupErrorContinue = 1 << 5, // Line's background is drawn in red to mark an execution error on continue.
+    LineMarkupErrorContinue = 1 << 5, // Marker for a failed sql statement (execution).
 
     LineMarkupAll = 0xFF, // All markup, useful for remove_markup.
   };
@@ -182,12 +183,15 @@ namespace mforms {
     std::map<std::string, std::string> get_keywords() {
       return _keywords;
     };
+
     std::map<std::string, std::string> get_properties() {
       return _properties;
     };
+
     std::map<std::string, std::string> get_settings() {
       return _settings;
     };
+    
     std::map<int, std::map<std::string, std::string> > get_styles() {
       return _styles;
     };
@@ -211,15 +215,15 @@ namespace mforms {
 #endif
 #endif
 
-  class MFORMS_EXPORT CodeEditor : public View {
+  class MFORMS_EXPORT CodeEditor : public View, public base::Observer {
   public:
     enum EditorMargin { LineNumberMargin, MarkersMargin, FolderMargin, TextMargin };
 
     CodeEditor(void* host = NULL, bool showInfo = true);
     ~CodeEditor();
 
-    /** Apply default settings for the editor. */
-    void setup();
+    /** Set editor colors based on the current OS appearance. */
+    void updateColors();
 
     /** Set custom color and size of editor margins. */
     void setWidth(EditorMargin margin, int size, const std::string& adjustText = "");
@@ -253,7 +257,7 @@ namespace mforms {
      *  string in that case.
      */
     const std::string get_text(bool selection_only);
-    virtual std::string get_string_value() {
+    virtual std::string get_string_value() override {
       return get_text(false);
     }
 
@@ -327,7 +331,7 @@ namespace mforms {
     /** Returns the line number from the given character position. */
     size_t line_from_position(size_t position);
 
-    void set_font(const std::string& fontDescription); // e.g. "Trebuchet MS bold 9"
+    virtual void set_font(const std::string& fontDescription) override; // e.g. "Trebuchet MS bold 9"
 
     /** Enables or disables different features in the editor which have a yes/no behavior. */
     void set_features(CodeEditorFeature features, bool flag);
@@ -555,33 +559,38 @@ namespace mforms {
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
     /** Called by the platform code forwarding us all scintilla notifications, so we can act on them. */
-    void on_notify(Scintilla::SCNotification* notification);
+    void on_notify(SCNotification* notification);
 
     /** Called by the platform code forwarding us all scintilla commands, so we can act on them. */
     void on_command(int command);
     void lost_focus();
     bool key_event(mforms::KeyCode code, mforms::ModifierKey modifier, const std::string& text);
 
-    virtual void resize();
+    virtual void resize() override;
 
 #endif
 #endif
-  protected:
+
+  private:
     CodeEditorImplPtrs* _code_editor_impl;
     Menu* _context_menu;
     FindPanel* _find_panel;
-    std::map<int, void*> _images; // Registered RGBA images.
+
+    std::map<int, std::map<std::string, std::string>> _currentStyles; // Loaded styles for the currently configured langugage.
+
     void* _host;
     bool _scroll_on_resize;
     bool _auto_indent;
 
     MarginSizes _marginSize;
 
-    void setup_marker(int marker, const std::string& name);
+    void setupMarker(int marker, const std::string& name);
     void handleMarkerDeletion(int position, int length);
     void handleMarkerMove(int position, int linesAdded);
+    bool ensureImage(std::string const& name);
 
-    void load_configuration(SyntaxHighlighterLanguage language);
+    void loadConfiguration(SyntaxHighlighterLanguage language);
+    virtual void handle_notification(const std::string &name, void *sender, base::NotificationInfo &info) override;
 
     boost::signals2::signal<void(int, int, int, bool)> _change_event;
     boost::signals2::signal<void(int, int, mforms::ModifierKey)> _gutter_clicked_event;
