@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2008, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #pragma once
@@ -46,10 +50,7 @@ namespace mforms {
     MiddleRight,
     TopLeft,
     TopCenter,
-    TopRight,
-
-    //
-    WizardLabelAlignment
+    TopRight
   };
 
   struct TextAttributes {
@@ -57,7 +58,7 @@ namespace mforms {
     bool bold;
     bool italic;
     base::Color color;
-    TextAttributes() : bold(false), italic(false), color(base::Color::Invalid()) {
+    TextAttributes() : bold(false), italic(false), color(base::Color::invalid()) {
     }
 #endif
     TextAttributes(const std::string &c, bool b, bool i) : bold(b), italic(i), color(base::Color::parse(c)) {
@@ -75,6 +76,18 @@ namespace mforms {
             // TODO: identify hard coded values and replace them.
   };
 
+  enum class Modifier {
+    NoModifier   = 0x00,
+    ShiftLeft    = 0x01,
+    ShiftRight   = 0x02,
+    ControlLeft  = 0x04,
+    ControlRight = 0x08,
+    AltLeft      = 0x10,
+    AltRight     = 0x20,
+    MetaLeft     = 0x40,
+    MetaRight    = 0x80
+  };
+
   enum DragOperation {
     DragOperationNone = 0,
     DragOperationCopy = 1 << 0,
@@ -152,7 +165,7 @@ namespace mforms {
     virtual DragOperation files_dropped(View *sender, base::Point p, DragOperation allowedOperations,
                                         const std::vector<std::string> &file_names) {
       return DragOperationNone;
-    };
+    }
 
     /**
      * Called when text was dropped on the receiver (only called if drag_over returned a valid drag operation).
@@ -161,7 +174,7 @@ namespace mforms {
     virtual DragOperation text_dropped(View *sender, base::Point p, DragOperation allowedOperations,
                                        const std::string &text) {
       return DragOperationNone;
-    };
+    }
 
     /**
      * Called when any custom data was dropped on the receiver (only called if drag_over returned a valid drag
@@ -174,7 +187,7 @@ namespace mforms {
     virtual DragOperation data_dropped(View *sender, base::Point p, DragOperation allowedOperations, void *data,
                                        const std::string &format) {
       return DragOperationNone;
-    };
+    }
   };
 #endif
 
@@ -236,7 +249,7 @@ namespace mforms {
     friend class ControlFactory;
 
   private:
-    std::string _name;
+    std::string _internalName;
     bool _layout_dirty;
 
     boost::signals2::signal<void()> _signal_resized;
@@ -269,12 +282,13 @@ namespace mforms {
     bool contains_subview(View *subview);
     void clear_subviews();
 
-    void set_name(const std::string &name);
+    virtual void set_name(const std::string &name);
+    void setInternalName(const std::string &name);
+    std::string getInternalName() const;
     void set_tooltip(const std::string &text);
     virtual void set_font(const std::string &fontDescription); // e.g. "Trebuchet MS bold 9"
-    std::string get_name();
     void set_parent(View *parent);
-    View *get_parent() const;
+    virtual View *get_parent() const;
     Form *get_parent_form() const;
     virtual int get_width() const;
     virtual int get_height() const;
@@ -444,6 +458,22 @@ namespace mforms {
     virtual bool mouse_move(MouseButton button, int x, int y) {
       return false;
     }
+
+    virtual bool focusIn() {
+    	return false;
+    }
+
+    virtual bool focusOut() {
+    	return false;
+    }
+
+    virtual bool keyPress(KeyCode code, ModifierKey modifiers) {
+    	return false;
+    }
+
+    virtual bool keyRelease(KeyCode code, ModifierKey modifiers) {
+    	return false;
+    }
 #endif
 #endif
 
