@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "mforms/mforms.h"
@@ -28,7 +32,7 @@ DEFAULT_LOG_DOMAIN("mforms");
 
 #ifdef __APPLE__
 #define TAB_FONT "Lucida Grande"
-#elif _WIN32
+#elif _MSC_VER
 #define TAB_FONT "Tahoma"
 #else
 #define TAB_FONT "Helvetica"
@@ -42,7 +46,7 @@ DEFAULT_LOG_DOMAIN("mforms");
 
 #define INITIAL_TAB_HEIGHT 58
 
-#ifdef _WIN32
+#ifdef _MSC_VER
 #define VERTICAL_STYLE_WIDTH 58
 #define VERTICAL_STYLE_HEIGHT 68
 #else
@@ -50,7 +54,7 @@ DEFAULT_LOG_DOMAIN("mforms");
 #define VERTICAL_STYLE_HEIGHT 70
 #endif
 
-#ifndef _WIN32
+#ifndef _MSC_VER
 using std::max;
 #endif
 
@@ -63,14 +67,18 @@ const int PREV_BUTTON_INDEX = -3;
 //--------------------------------------------------------------------------------------------------
 
 class mforms::TabSwitcherPimpl {
-protected:
-  struct TabItem {
+public:
+  class TabItem : public Accessible {
+  public:
     std::string title;
     std::string sub_title;
     cairo_surface_t *icon;
     cairo_surface_t *alt_icon;
+    base::Rect accBounds;   // Bounds to be used for accessibility
+    std::function<void(int x, int y)> actionCallback;
 
-    TabItem() : icon(0), alt_icon(0) {
+    TabItem(const std::function<void(int x, int y)> &clickCallback) : icon(0), alt_icon(0) {
+      actionCallback = clickCallback;
     }
     ~TabItem() {
       if (icon)
@@ -78,14 +86,33 @@ protected:
       if (alt_icon)
         cairo_surface_destroy(alt_icon);
     }
+
+    // ------ Accesibility Methods -----
+    virtual Accessible::Role getAccessibilityRole() override {
+      return Accessible::ListItem;
+    }
+
+    virtual base::Rect getAccessibilityBounds() override {
+      return accBounds;
+    }
+
+    virtual std::string getAccessibilityDefaultAction() override {
+      return "Switch view";
+    }
+
+    virtual void accessibilityDoDefaultAction() override {
+      actionCallback((int)accBounds.center().x, (int)accBounds.center().y);
+    }
   };
 
+protected:
   TabSwitcher *_owner;
   std::vector<TabItem *> _items;
 
   int _selected;
   int _last_clicked;
 
+
   TabSwitcherPimpl(TabSwitcher *owner) : _owner(owner), _selected(-1), _last_clicked(-1) {
   }
 
@@ -109,6 +136,18 @@ public:
     return _selected;
   }
 
+  std::size_t getItemCount() {
+    return _items.size();
+  }
+
+  TabItem *getItem(int index) {
+    try {
+      return _items[index];
+    } catch (...) {
+      return nullptr;
+    }
+  }
+
   virtual void repaint(cairo_t *cr, int areax, int areay, int areaw, int areah) = 0;
 
   virtual void set_icon(int index, const std::string &icon_path, const std::string &alt_icon_path) {
@@ -127,8 +166,20 @@ public:
 
   virtual int add_item(const std::string &title, const std::string &sub_title, const std::string &icon_path,
                        const std::string &alt_icon_path) {
-    TabItem *item = new TabItem();
 
+    TabItem *item = new TabItem([&](int x, int y) {
+      if (_owner != nullptr) {
+        int index = index_from_point(x, y);
+        if (index != -1) {
+          _owner->set_selected(index);
+          (*_owner->signal_changed())();
+        }
+
+      }
+
+    });
+
+    item->setAccessibilityName(title);
     item->title = title;
     item->sub_title = sub_title;
     item->icon = Utilities::load_icon(icon_path, true);
@@ -182,18 +233,18 @@ class VerticalTabSwitcher : public mforms::TabSwitcherPimpl {
 
 public:
   VerticalTabSwitcher(TabSwitcher *owner)
-    : TabSwitcherPimpl(owner), _first_visible(0), _last_visible(0), _collapsed(false) {
-#ifdef _WIN32
+    : TabSwitcherPimpl(owner), _up_arrow_y(0), _down_arrow_y(0), _first_visible(0), _last_visible(0), _collapsed(false) {
+#ifdef _MSC_VER
     if (base::Color::get_active_scheme() != base::ColorSchemeStandardWin7) {
-      _colors[TabInactiveBackground] = base::Color::get_application_color(base::AppColorPanelHeader, false);
-      _colors[TabInactiveForeground] = base::Color::get_application_color(base::AppColorPanelHeader, true);
-      _colors[TabActiveBackground] = base::Color::get_application_color(base::AppColorPanelHeaderFocused, false);
-      _colors[TabActiveForeground] = base::Color::get_application_color(base::AppColorPanelHeaderFocused, true);
+      _colors[TabInactiveBackground] = base::Color::getApplicationColor(base::AppColorPanelHeader, false);
+      _colors[TabInactiveForeground] = base::Color::getApplicationColor(base::AppColorPanelHeader, true);
+      _colors[TabActiveBackground] = base::Color::getApplicationColor(base::AppColorPanelHeaderFocused, false);
+      _colors[TabActiveForeground] = base::Color::getApplicationColor(base::AppColorPanelHeaderFocused, true);
     } else {
-      _colors[TabInactiveBackground] = base::Color::get_application_color(base::AppColorPanelHeader, false);
-      _colors[TabInactiveForeground] = base::Color::get_application_color(base::AppColorPanelHeader, true);
-      _colors[TabActiveBackground] = base::Color::get_application_color(base::AppColorMainBackground, false);
-      _colors[TabActiveForeground] = base::Color::get_application_color(base::AppColorPanelHeader, true);
+      _colors[TabInactiveBackground] = base::Color::getApplicationColor(base::AppColorPanelHeader, false);
+      _colors[TabInactiveForeground] = base::Color::getApplicationColor(base::AppColorPanelHeader, true);
+      _colors[TabActiveBackground] = base::Color::getApplicationColor(base::AppColorMainBackground, false);
+      _colors[TabActiveForeground] = base::Color::getApplicationColor(base::AppColorPanelHeader, true);
     }
 #else
     _colors[TabInactiveBackground] = Color(0x48 / 255.0, 0x48 / 255.0, 0x48 / 255.0, 1);
@@ -245,15 +296,28 @@ public:
 
     _last_visible = _first_visible;
     for (std::vector<TabItem *>::iterator i = _items.begin(); i != _items.end(); ++i, ++ii) {
-      if (ii < _first_visible)
-        continue;
 
-      if (y + VERTICAL_STYLE_HEIGHT > _owner->get_height())
-        break;
+
+      base::Size size = Utilities::getImageSize((*i)->icon);
+      (*i)->accBounds.size = size;
+      (*i)->accBounds.pos.x = (VERTICAL_STYLE_WIDTH - (VERTICAL_STYLE_WIDTH / 64.0) * size.width) / 2;
+
+      if (ii < _first_visible) {
+        (*i)->accBounds.pos.y = ((VERTICAL_STYLE_WIDTH - size.height) / 2 - font_size) - (_first_visible - ii) * VERTICAL_STYLE_HEIGHT;
+        continue;
+      }
+
+      (*i)->accBounds.pos.y = iy + (VERTICAL_STYLE_WIDTH - size.height) / 2 - font_size;
+
+      if (y + VERTICAL_STYLE_HEIGHT > _owner->get_height()) {
+        iy += VERTICAL_STYLE_HEIGHT;
+        continue;
+      }
 
       _last_visible = ii;
 
-      base::Size size = Utilities::getImageSize((*i)->icon);
+
+
 
       if (_selected == ii) {
         color = _colors[TabActiveBackground];
@@ -264,8 +328,9 @@ public:
         Utilities::paint_icon(cr, _selection_image, 0, iy + (VERTICAL_STYLE_WIDTH - size.width) / 2 + size.height / 2);
       }
 
-      Utilities::paint_icon(cr, (*i)->icon, (VERTICAL_STYLE_WIDTH - (VERTICAL_STYLE_WIDTH / 64.0) * size.width) / 2,
-                            iy + (VERTICAL_STYLE_WIDTH - size.height) / 2 - font_size, _selected == ii ? 1.0f : 0.4f);
+      Utilities::paint_icon(cr, (*i)->icon, (*i)->accBounds.pos.x, (*i)->accBounds.pos.y,
+                                                    _selected == ii ? 1.0f : 0.4f);
+
       if (_selected == ii) {
         color = _colors[TabActiveForeground];
       } else {
@@ -387,7 +452,7 @@ public:
 
 //--------------------------------------------------------------------------------------------------
 
-TabSwitcher::TabSwitcher(TabSwitcherType type) : _tabView(0), _needs_relayout(true), _was_collapsed(false) {
+TabSwitcher::TabSwitcher(TabSwitcherType type) : _tabView(0), _last_clicked(-1), _needs_relayout(true), _was_collapsed(false) {
   _timeout = 0;
   switch (type) {
     case VerticalIconSwitcher:
@@ -570,6 +635,34 @@ bool TabSwitcher::mouse_leave() {
 
 //--------------------------------------------------------------------------------------------------
 
+size_t TabSwitcher::getAccessibilityChildCount() {
+  return _pimpl->getItemCount();
+}
+
+//--------------------------------------------------------------------------------------------------
+
+Accessible *TabSwitcher::getAccessibilityChild(size_t index) {
+  return dynamic_cast<Accessible*>(_pimpl->getItem(static_cast<int>(index)));
+}
+
+//--------------------------------------------------------------------------------------------------
+
+Accessible::Role TabSwitcher::getAccessibilityRole() {
+  return Accessible::List;
+}
+
+//--------------------------------------------------------------------------------------------------
+
+base::Accessible *TabSwitcher::accessibilityHitTest(ssize_t x, ssize_t y) {
+  int idx = _pimpl->index_from_point(static_cast<int>(x), static_cast<int>(y));
+  if (idx == -1)
+    return nullptr;
+  else
+    return _pimpl->getItem(idx);
+}
+
+//--------------------------------------------------------------------------------------------------
+
 void TabSwitcher::repaint(cairo_t *cr, int areax, int areay, int areaw, int areah) {
   _pimpl->repaint(cr, areax, areay, areaw, areah);
 }
