@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2008, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 /**
@@ -131,7 +135,7 @@ void View::remove_from_cache(View *sv) {
 View *View::find_subview(const std::string &name) {
   for (std::vector<std::pair<View *, bool> >::const_iterator iter = _subviews.begin(); iter != _subviews.end();
        ++iter) {
-    if (iter->first->get_name() == name)
+    if (iter->first->getInternalName() == name)
       return iter->first;
 
     View *sv = iter->first->find_subview(name);
@@ -180,8 +184,6 @@ bool View::contains_subview(View *subview) {
 //--------------------------------------------------------------------------------------------------
 
 void View::set_name(const std::string &name) {
-  _name = name;
-
   // Optional implementation.
   if (_view_impl->set_name)
     _view_impl->set_name(this, name);
@@ -201,10 +203,17 @@ void View::set_font(const std::string &fontDescription) {
 
 //--------------------------------------------------------------------------------------------------
 
-std::string View::get_name() {
-  return _name;
+void View::setInternalName(const std::string &name) {
+  _internalName = name;
 }
 
+//--------------------------------------------------------------------------------------------------
+
+std::string View::getInternalName() const {
+    return _internalName;
+}
+
+
 //--------------------------------------------------------------------------------------------------
 
 void View::set_parent(View *parent) {
