@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include "wf_base.h"
@@ -51,55 +55,55 @@ static int convert_mouse_button(MouseButtons button) {
 
 //--------------------------------------------------------------------------------------------------
 
-static System::Windows::Forms::AccessibleRole convert_accessible_role(mforms::Accessible::Role be_role) {
+static System::Windows::Forms::AccessibleRole convert_accessible_role(base::Accessible::Role be_role) {
   System::Windows::Forms::AccessibleRole role = System::Windows::Forms::AccessibleRole::None;
 
   switch (be_role) {
-    case mforms::Accessible::RoleNone:
+    case base::Accessible::RoleNone:
       role = System::Windows::Forms::AccessibleRole::None;
       break;
 
-    case mforms::Accessible::Client:
-      role = System::Windows::Forms::AccessibleRole::Client;
+    case base::Accessible::Window:
+      role = System::Windows::Forms::AccessibleRole::Window;
       break;
 
-    case mforms::Accessible::Pane:
+    case base::Accessible::Pane:
       role = System::Windows::Forms::AccessibleRole::Pane;
       break;
 
-    case mforms::Accessible::Link:
+    case base::Accessible::Link:
       role = System::Windows::Forms::AccessibleRole::Link;
       break;
 
-    case mforms::Accessible::List:
+    case base::Accessible::List:
       role = System::Windows::Forms::AccessibleRole::List;
       break;
 
-    case mforms::Accessible::ListItem:
+    case base::Accessible::ListItem:
       role = System::Windows::Forms::AccessibleRole::ListItem;
       break;
 
-    case mforms::Accessible::PushButton:
+    case base::Accessible::PushButton:
       role = System::Windows::Forms::AccessibleRole::PushButton;
       break;
 
-    case mforms::Accessible::StaticText:
+    case base::Accessible::StaticText:
       role = System::Windows::Forms::AccessibleRole::StaticText;
       break;
 
-    case mforms::Accessible::Text:
+    case base::Accessible::Text:
       role = System::Windows::Forms::AccessibleRole::Text;
       break;
 
-    case mforms::Accessible::Outline:
+    case base::Accessible::Outline:
       role = System::Windows::Forms::AccessibleRole::Outline;
       break;
 
-    case mforms::Accessible::OutlineButton:
+    case base::Accessible::OutlineButton:
       role = System::Windows::Forms::AccessibleRole::OutlineButton;
       break;
 
-    case mforms::Accessible::OutlineItem:
+    case base::Accessible::OutlineItem:
       role = System::Windows::Forms::AccessibleRole::OutlineItem;
       break;
   }
@@ -108,7 +112,7 @@ static System::Windows::Forms::AccessibleRole convert_accessible_role(mforms::Ac
 
 //----------------- WBControlAccessibleObject ------------------------------------------------------
 
-WBControlAccessibleObject::WBControlAccessibleObject(Control ^ owner, mforms::Accessible *backendOwner)
+WBControlAccessibleObject::WBControlAccessibleObject(Control ^ owner, base::Accessible *backendOwner)
   : ControlAccessibleObject(owner) {
   backend = backendOwner;
 }
@@ -116,49 +120,49 @@ WBControlAccessibleObject::WBControlAccessibleObject(Control ^ owner, mforms::Ac
 //--------------------------------------------------------------------------------------------------
 
 String ^ WBControlAccessibleObject::Name::get() {
-  return CppStringToNativeRaw(backend->get_acc_name());
+  return CppStringToNativeRaw(backend->getAccessibilityName());
 }
 
 //--------------------------------------------------------------------------------------------------
 
 int WBControlAccessibleObject::GetChildCount() {
-  return backend->get_acc_child_count();
+  return static_cast<int>(backend->getAccessibilityChildCount());
 }
 
 //--------------------------------------------------------------------------------------------------
 
 String ^ WBControlAccessibleObject::Description::get() {
-  return CppStringToNative(backend->get_acc_description());
+  return CppStringToNative(backend->getAccessibilityDescription());
 }
 
 //--------------------------------------------------------------------------------------------------
 
 String ^ WBControlAccessibleObject::DefaultAction::get() {
-  return CppStringToNativeRaw(backend->get_acc_default_action());
+  return CppStringToNativeRaw(backend->getAccessibilityDefaultAction());
 }
 
 //--------------------------------------------------------------------------------------------------
 
 String ^ WBControlAccessibleObject::Value::get() {
-  return CppStringToNative(backend->get_acc_value());
+  return CppStringToNative(backend->getAccessibilityValue());
 }
 
 //--------------------------------------------------------------------------------------------------
 
 System::Windows::Forms::AccessibleRole WBControlAccessibleObject::Role::get() {
-  return convert_accessible_role(backend->get_acc_role());
+  return convert_accessible_role(backend->getAccessibilityRole());
 }
 
 //--------------------------------------------------------------------------------------------------
 
 void WBControlAccessibleObject::DoDefaultAction() {
-  return backend->do_default_action();
+  return backend->accessibilityDoDefaultAction();
 }
 
 //--------------------------------------------------------------------------------------------------
 
 System::Windows::Forms::AccessibleObject ^ WBControlAccessibleObject::GetChild(int index) {
-  mforms::Accessible *child = backend->get_acc_child(index);
+  base::Accessible *child = backend->getAccessibilityChild(index);
 
   if (child)
     return gcnew WBAccessibleObject(child, this);
@@ -171,7 +175,7 @@ System::Windows::Forms::AccessibleObject ^ WBControlAccessibleObject::GetChild(i
 System::Windows::Forms::AccessibleObject ^ WBControlAccessibleObject::HitTest(int x, int y) {
   Point point = Owner->PointToClient(Point(x, y));
 
-  mforms::Accessible *accessible = backend->hit_test(point.X, point.Y);
+  base::Accessible *accessible = backend->accessibilityHitTest(point.X, point.Y);
 
   if (accessible)
     return gcnew WBAccessibleObject(accessible, this);
@@ -183,7 +187,7 @@ System::Windows::Forms::AccessibleObject ^ WBControlAccessibleObject::HitTest(in
 
 //----------------- WBAccessibleObject -------------------------------------------------------------
 
-WBAccessibleObject::WBAccessibleObject(mforms::Accessible *backendOwner, WBControlAccessibleObject ^ parent_control) {
+WBAccessibleObject::WBAccessibleObject(base::Accessible *backendOwner, WBControlAccessibleObject ^ parent_control) {
   backend = backendOwner;
   parent = parent_control;
 }
@@ -191,37 +195,37 @@ WBAccessibleObject::WBAccessibleObject(mforms::Accessible *backendOwner, WBContr
 //--------------------------------------------------------------------------------------------------
 
 String ^ WBAccessibleObject::Name::get() {
-  return CppStringToNativeRaw(backend->get_acc_name());
+  return CppStringToNativeRaw(backend->getAccessibilityName());
 }
 
 //--------------------------------------------------------------------------------------------------
 
 String ^ WBAccessibleObject::Description::get() {
-  return CppStringToNative(backend->get_acc_description());
+  return CppStringToNative(backend->getAccessibilityDescription());
 }
 
 //--------------------------------------------------------------------------------------------------
 
 String ^ WBAccessibleObject::DefaultAction::get() {
-  return CppStringToNativeRaw(backend->get_acc_default_action());
+  return CppStringToNativeRaw(backend->getAccessibilityDefaultAction());
 }
 
 //--------------------------------------------------------------------------------------------------
 
 String ^ WBAccessibleObject::Value::get() {
-  return CppStringToNative(backend->get_acc_value());
+  return CppStringToNative(backend->getAccessibilityValue());
 }
 
 //--------------------------------------------------------------------------------------------------
 
 System::Windows::Forms::AccessibleRole WBAccessibleObject::Role::get() {
-  return convert_accessible_role(backend->get_acc_role());
+  return convert_accessible_role(backend->getAccessibilityRole());
 }
 
 //--------------------------------------------------------------------------------------------------
 
 System::Drawing::Rectangle WBAccessibleObject::Bounds::get() {
-  base::Rect backend_bounds = backend->get_acc_bounds();
+  base::Rect backend_bounds = backend->getAccessibilityBounds();
   System::Drawing::Rectangle bounds = System::Drawing::Rectangle(
     (int)backend_bounds.left(), (int)backend_bounds.top(), (int)backend_bounds.width(), (int)backend_bounds.height());
 
@@ -234,19 +238,19 @@ System::Drawing::Rectangle WBAccessibleObject::Bounds::get() {
 //--------------------------------------------------------------------------------------------------
 
 int WBAccessibleObject::GetChildCount() {
-  return backend->get_acc_child_count();
+  return static_cast<int>(backend->getAccessibilityChildCount());
 }
 
 //--------------------------------------------------------------------------------------------------
 
 void WBAccessibleObject::DoDefaultAction() {
-  return backend->do_default_action();
+  return backend->accessibilityDoDefaultAction();
 }
 
 //--------------------------------------------------------------------------------------------------
 
 System::Windows::Forms::AccessibleObject ^ WBAccessibleObject::GetChild(int index) {
-  mforms::Accessible *child = backend->get_acc_child(index);
+  base::Accessible *child = backend->getAccessibilityChild(index);
 
   if (child)
     return gcnew WBAccessibleObject(child, parent);
@@ -257,7 +261,7 @@ System::Windows::Forms::AccessibleObject ^ WBAccessibleObject::GetChild(int inde
 //--------------------------------------------------------------------------------------------------
 
 System::Windows::Forms::AccessibleObject ^ WBAccessibleObject::HitTest(int x, int y) {
-  mforms::Accessible *accessible = backend->hit_test(x, y);
+  base::Accessible *accessible = backend->accessibilityHitTest(x, y);
 
   if (accessible && accessible != backend)
     return gcnew WBAccessibleObject(accessible, parent);
@@ -345,9 +349,8 @@ void CanvasControl::DoRepaint() {
 
 //--------------------------------------------------------------------------------------------------
 
-void CanvasControl::OnKeyDown(KeyEventArgs ^ args) {
-  __super ::OnKeyDown(args);
-
+void CanvasControl::OnKeyDown(KeyEventArgs ^args) {
+  __super::OnKeyDown(args);
   if (args->KeyCode == Keys::Escape)
     backend->cancel_operation();
 }
@@ -373,7 +376,7 @@ void CanvasControl::OnPaint(PaintEventArgs ^ args) {
 //----------------- DrawBoxLayout ------------------------------------------------------------------
 
 bool DrawBoxLayout::Layout(Object ^ sender, LayoutEventArgs ^ arguments) {
-  CanvasControl ^ canvas = (CanvasControl ^)sender;
+  CanvasControl ^ canvas = (CanvasControl ^) sender;
   Size canvasSize = canvas->Size;
   for each(Control ^ control in canvas->Controls) {
       int x, y;
@@ -478,6 +481,19 @@ void DrawBoxWrapper::move(mforms::DrawBox *backend, mforms::View *view, int x, i
 
 //--------------------------------------------------------------------------------------------------
 
+void DrawBoxWrapper::drawFocus(::mforms::DrawBox *self, cairo_t *cr, const base::Rect r) {
+  auto bounds = r;
+  bounds.use_inter_pixel = true;
+  cairo_set_source_rgba(cr, 0.0, 0.0, 0.0, 1.0);
+  cairo_rectangle(cr, bounds.left(), bounds.top(), bounds.width() - 2, bounds.height() - 2);
+  double dashes[] = { 1.0, 2.0 };
+  cairo_set_dash(cr, dashes, 2, 0);
+  cairo_set_line_width(cr, 1);
+  cairo_stroke(cr);
+}
+
+//--------------------------------------------------------------------------------------------------
+
 void DrawBoxWrapper::init() {
   mforms::ControlFactory *f = mforms::ControlFactory::get_instance();
 
@@ -486,6 +502,7 @@ void DrawBoxWrapper::init() {
   f->_drawbox_impl.add = &DrawBoxWrapper::add;
   f->_drawbox_impl.remove = &DrawBoxWrapper::remove;
   f->_drawbox_impl.move = &DrawBoxWrapper::move;
+  f->_drawbox_impl.drawFocus = &DrawBoxWrapper::drawFocus;
 }
 
 //--------------------------------------------------------------------------------------------------
