@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "wf_base.h"
@@ -386,21 +390,13 @@ ToolBarItemWrapper::ToolBarItemWrapper(mforms::ToolBarItem *backend, mforms::Too
       break;
     }
 
-    case mforms::SwitcherItem: {
-      ToolStripButton ^ button = ToolBarItemWrapper::Create<ToolStripButton>(backend, this);
-      button->Click += gcnew System::EventHandler(eventTarget, &ToolbarItemEventTarget::OnItemActivation);
-      button->ForeColor = Conversions::GetApplicationColor(ApplicationColor::AppColorPanelToolbar, true);
-      item = button;
-      break;
-    }
-
     default:
       throw std::runtime_error(
         base::strfmt("Internal error: unimplemented toolbar item type requested (%i).", (int)type));
   }
 
   item->ImageScaling = ToolStripItemImageScaling::None;
-  item->Name = CppStringToNative(backend->get_name());
+  item->Name = CppStringToNative(backend->getInternalName());
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -567,8 +563,7 @@ void ToolBarWrapper::insert_item(mforms::ToolBar *backend, int index, mforms::To
   ToolStripItem ^ native_item = ToolBarWrapper::GetManagedObject<ToolStripItem>(item);
 
   // Update the name of the control, so the accessibility layer has something to work with.
-  native_item->Name = CppStringToNative(item->get_name());
-  native_item->AccessibleName = native_item->Name;
+  native_item->Name = CppStringToNative(item->getInternalName());
 
   if (index < 0 || index >= toolstrip->Items->Count) {
     index = toolstrip->Items->Count;
@@ -669,7 +664,8 @@ std::string ToolBarWrapper::get_item_text(mforms::ToolBarItem *item) {
 //--------------------------------------------------------------------------------------------------
 
 void ToolBarWrapper::set_item_name(mforms::ToolBarItem *item, const std::string &name) {
-  // This is dummy function to silent warnings
+  ToolStripItem ^ native_item = ToolBarWrapper::GetManagedObject<ToolStripItem>(item);
+  native_item->AccessibleName = CppStringToNative(name);
 }
 
 //--------------------------------------------------------------------------------------------------
