@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2008, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "base/log.h"
@@ -167,6 +171,143 @@ public:
 
   //------------------------------------------------------------------------------------------------
 
+  void HandlerFocusIn(System::Object ^sender, EventArgs ^e) {
+    mforms::View *ownedView = ViewWrapper::GetBackend<mforms::View>(sender);
+    if (ownedView != nullptr) {
+      ownedView->focusIn();
+    }
+  }
+
+  //------------------------------------------------------------------------------------------------
+
+  void HandlerFocusOut(System::Object ^sender, EventArgs ^e) {
+    mforms::View *ownedView = ViewWrapper::GetBackend<mforms::View>(sender);
+    if (ownedView != nullptr) {
+      ownedView->focusOut();
+    }
+  }
+
+  //------------------------------------------------------------------------------------------------
+
+  void HandlerPreviewKeyKeyDown(System::Object ^sender, PreviewKeyDownEventArgs ^e) {
+    if (e->KeyCode == Keys::Tab) {
+      mforms::View *ownedView = ViewWrapper::GetBackend<mforms::View>(sender);
+      if (ownedView != nullptr) {
+        e->IsInputKey = ownedView->keyPress(GetKeys(e->KeyCode), ViewWrapper::GetModifiers(e->KeyData));
+      }
+    }
+  }
+
+  //------------------------------------------------------------------------------------------------
+
+  void HandlerKeyDown(System::Object ^sender, KeyEventArgs ^e) {
+    mforms::View *ownedView = ViewWrapper::GetBackend<mforms::View>(sender);
+    if (e->KeyCode == Keys::Tab) {
+      e->Handled = true;
+    } else {
+      mforms::View *ownedView = ViewWrapper::GetBackend<mforms::View>(sender);
+      if (ownedView != nullptr) {
+        e->Handled = ownedView->keyPress(GetKeys(e->KeyCode), ViewWrapper::GetModifiers(e->KeyData));
+      }
+    }
+  }
+  
+  //------------------------------------------------------------------------------------------------
+
+
+  void HandlerKeyUp(System::Object ^sender, KeyEventArgs ^e) {
+    mforms::View *ownedView = ViewWrapper::GetBackend<mforms::View>(sender);
+    if (ownedView != nullptr) {
+      ownedView->keyRelease(GetKeys(e->KeyCode), ViewWrapper::GetModifiers(e->KeyData));
+    }
+  }
+
+  //------------------------------------------------------------------------------------------------
+
+  mforms::KeyCode GetKeys(System::Windows::Forms::Keys arg) {
+    mforms::KeyCode code = mforms::KeyUnkown;
+    switch (arg) {
+    case Keys::Home:
+      code = mforms::KeyHome;
+      break;
+    case Keys::End:
+      code = mforms::KeyEnd;
+      break;
+    case Keys::PageUp:
+      code = mforms::KeyPrevious;
+      break;
+    case Keys::PageDown:
+      code = mforms::KeyNext;
+      break;
+    case Keys::Up:
+      code = mforms::KeyUp;
+      break;
+    case Keys::Down:
+      code = mforms::KeyDown;
+      break;
+    case Keys::Return:
+      code = mforms::KeyReturn;
+      break;
+    case Keys::Tab:
+      code = mforms::KeyTab;
+      break;
+    case Keys::Apps:
+      code = mforms::KeyMenu;
+      break;
+    case  Keys::F1:
+      code = mforms::KeyF1;
+      break;
+    case  Keys::F2:
+      code = mforms::KeyF2;
+      break;
+    case  Keys::F3:
+      code = mforms::KeyF3;
+      break;
+    case  Keys::F4:
+      code = mforms::KeyF4;
+      break;
+    case  Keys::F5:
+      code = mforms::KeyF5;
+      break;
+    case  Keys::F6:
+      code = mforms::KeyF6;
+      break;
+    case  Keys::F7:
+      code = mforms::KeyF7;
+      break;
+    case  Keys::F8:
+      code = mforms::KeyF8;
+      break;
+    case  Keys::F9:
+      code = mforms::KeyF9;
+      break;
+    case  Keys::F10:
+      code = mforms::KeyF10;
+      break;
+    case  Keys::F11:
+      code = mforms::KeyF11;
+      break;
+    case  Keys::F12:
+      code = mforms::KeyF12;
+      break;
+    case Keys::LShiftKey:
+    case Keys::RShiftKey:
+    case Keys::LControlKey:
+    case Keys::RControlKey:
+    case Keys::LWin:
+    case Keys::RWin:
+      code = mforms::KeyModifierOnly;
+      break;
+    default:
+      if (arg >= Keys::A && arg <= Keys::Z)
+        code = mforms::KeyChar;
+      break;
+    }
+    return code;
+  }
+
+  //------------------------------------------------------------------------------------------------
+
   std::vector<std::string> get_available_formats(System::Windows::Forms::IDataObject ^ data) {
     std::vector<std::string> result;
     array<String ^> ^ formats = data->GetFormats();
@@ -1147,6 +1288,11 @@ void ViewWrapper::Initialize() {
       control->DragDrop += gcnew DragEventHandler(eventTarget, &ViewEventTarget::HandleDragDrop);
       control->DragOver += gcnew DragEventHandler(eventTarget, &ViewEventTarget::HandleDragOver);
       control->DragLeave += gcnew EventHandler(eventTarget, &ViewEventTarget::HandleDragLeave);
+      control->GotFocus += gcnew EventHandler(eventTarget, &ViewEventTarget::HandlerFocusIn);
+      control->LostFocus += gcnew EventHandler(eventTarget, &ViewEventTarget::HandlerFocusOut);
+      control->PreviewKeyDown += gcnew PreviewKeyDownEventHandler(eventTarget, &ViewEventTarget::HandlerPreviewKeyKeyDown);
+      control->KeyDown += gcnew KeyEventHandler(eventTarget, &ViewEventTarget::HandlerKeyDown);
+      control->KeyUp += gcnew KeyEventHandler(eventTarget, &ViewEventTarget::HandlerKeyUp);
     }
   }
 };
@@ -1177,6 +1323,8 @@ mforms::ModifierKey ViewWrapper::GetModifiers(Keys keyData) {
     modifiers = modifiers | mforms::ModifierShift;
   if ((keyData & Keys::LWin) == Keys::LWin)
     modifiers = modifiers | mforms::ModifierCommand;
+  if ((keyData & Keys::RWin) == Keys::RWin)
+    modifiers = modifiers | mforms::ModifierCommand;
   return modifiers;
 }
 
