@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2007, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #pragma once
@@ -33,10 +37,9 @@
 #include <libxml/xmlmemory.h>
 #include "base/threading.h"
 #include <string>
-#include <gmodule.h>
 
 #ifndef _NODLL_
-#if defined(_WIN32)
+#if defined(_MSC_VER)
 #pragma warning(disable : 4275)
 #pragma warning(disable : 4251)
 #ifdef MYSQLGRTLIBRARY_EXPORTS
@@ -391,11 +394,11 @@ namespace grt {
     }
 
     Ref(const Ref<Class> &ref) : ValueRef(ref) {
-#if defined(ENABLE_DEBUG) || defined(_DEBUG)
-#if __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ > 2) // this causes errors in mac, with gcc 4.2
+#if defined(WB_DEBUG)
+  #if __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ > 2) // this causes errors in mac, with gcc 4.2
       // just to give an error if Class is not an object
       Class::static_class_name();
-#endif
+  #endif
 #endif
     }
 
@@ -2206,8 +2209,8 @@ namespace grt {
     Module(ModuleLoader *loader);
     virtual ~Module() {
     }
-    virtual GModule *getGModule() {
-      return nullptr;
+
+    virtual void closeModule() noexcept {
     }
 
     std::string name() const {
@@ -2421,6 +2424,10 @@ namespace grt {
       return _verbose;
     }
 
+    // Set to true when we are running unit tests.
+    void setTesting(bool flag) { _testing = flag; };
+    bool testing() { return _testing; };
+
     // metaclasss
 
     /** Load metaclasses defined in a XML file.
@@ -2664,8 +2671,6 @@ namespace grt {
     void pop_status_query_handler();
     bool query_status();
 
-    void make_output_visible(void *sender = NULL);
-
     void send_error(const std::string &message, const std::string &details = "", void *sender = NULL);
     void send_warning(const std::string &message, const std::string &details = "", void *sender = NULL);
     void send_info(const std::string &message, const std::string &details = "", void *sender = NULL);
@@ -2711,11 +2716,6 @@ namespace grt {
 
     Shell *_shell;
 
-    // std::list<ModuleLoader*> _loaders;
-
-    // GStaticRecMutex _global_mutex;
-    // GStaticRWLock _global_tree_lock;
-
     void add_metaclass(MetaClass *stru);
     std::string module_path_in_bundle(const std::string &path);
 
@@ -2733,6 +2733,7 @@ namespace grt {
     bool _check_serialized_crc;
     bool _verbose;
     bool _scanning_modules;
+    bool _testing;
 
   private:
     GRT();
@@ -2740,7 +2741,6 @@ namespace grt {
     GRT &operator=(GRT &) = delete;
   };
 
-  //------------------------------------------------------------------------------------------------
   //------------------------------------------------------------------------------------------------
 
   template <class O>
