@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "testgrt.h"
@@ -25,7 +29,7 @@
 #include "grtdb/db_helpers.h"
 #include "wb_helpers.h"
 
-using namespace parser;
+using namespace parsers;
 using namespace tut;
 
 #define VERBOSE_TESTING 0
@@ -69,9 +73,7 @@ TEST_DATA_CONSTRUCTOR(grtdiff_alter_test) {
 
 TEST_DATA_DESTRUCTOR(grtdiff_alter_test) {
   std::auto_ptr<sql::Statement> stmt(connection->createStatement());
-  std::string sql_string = "DROP DATABASE IF EXISTS grtdiff_alter_test;";
-
-  execute_script(stmt.get(), sql_string);
+  stmt->execute("DROP DATABASE IF EXISTS grtdiff_alter_test;");
 }
 
 END_TEST_DATA_CLASS
@@ -84,7 +86,7 @@ TEST_FUNCTION(3) {
   schemata.push_back("grtdiff_alter_test");
   grt::GRT::get()->get_undo_manager()->disable();
   db_mysql_CatalogRef cat = tester->db_rev_eng_schema(schemata);
-  tester->wb->flush_idle_tasks();
+  tester->wb->flush_idle_tasks(false);
   tester->wb->close_document();
   tester->wb->close_document_finish();
 }
@@ -1062,8 +1064,8 @@ static struct {
   {NULL, NULL, NULL, NULL, NULL}};
 
 TEST_FUNCTION(10) {
-  std::shared_ptr<DiffChange> alter_change;
-  std::shared_ptr<DiffChange> empty_change;
+  std::shared_ptr<grt::DiffChange> alter_change;
+  std::shared_ptr<grt::DiffChange> empty_change;
 
   // column insertion
 
@@ -1079,16 +1081,16 @@ TEST_FUNCTION(10) {
   }
 
   MySQLParserServices::Ref services = MySQLParserServices::get();
-  parser::MySQLParserContext::Ref context =
-    services->createParserContext(tester->get_rdbms()->characterSets(), tester->get_rdbms()->version(), false);
+  parsers::MySQLParserContext::Ref context = services->createParserContext(tester->get_rdbms()->characterSets(),
+    tester->get_rdbms()->version(), "", false);
   grt::DictRef options(true);
   for (int i = 0; data[i].description != NULL; i++) {
-    std::cout << ".";
+    std::cout << "." << std::flush;
     if ((i + 1) % 30 == 0)
       std::cout << std::endl;
 
-    db_mysql_CatalogRef org_cat = create_empty_catalog_for_import();
-    db_mysql_CatalogRef mod_cat = create_empty_catalog_for_import();
+    db_mysql_CatalogRef org_cat = createEmptyCatalog();
+    db_mysql_CatalogRef mod_cat = createEmptyCatalog();
 
     {
       std::string org_script;
@@ -1219,8 +1221,8 @@ TEST_FUNCTION(10) {
 }
 
 TEST_FUNCTION(20) {
-  std::shared_ptr<DiffChange> alter_change;
-  std::shared_ptr<DiffChange> empty_change;
+  std::shared_ptr<grt::DiffChange> alter_change;
+  std::shared_ptr<grt::DiffChange> empty_change;
 
   // column insertion
   ensure("connection is NULL", connection.get() != NULL);
@@ -1235,8 +1237,8 @@ TEST_FUNCTION(20) {
   }
 
   MySQLParserServices::Ref services = MySQLParserServices::get();
-  MySQLParserContext::Ref context =
-    services->createParserContext(tester->get_rdbms()->characterSets(), tester->get_rdbms()->version(), false);
+  MySQLParserContext::Ref context = services->createParserContext(tester->get_rdbms()->characterSets(),
+    tester->get_rdbms()->version(), "", false);
 
   grt::DictRef options(true);
   for (int i = 0; data[i].description != NULL; i++) {
@@ -1245,8 +1247,8 @@ TEST_FUNCTION(20) {
       std::cout << std::endl;
 
     for (int j = 0; j <= 1; ++j) {
-      db_mysql_CatalogRef org_cat = create_empty_catalog_for_import();
-      db_mysql_CatalogRef mod_cat = create_empty_catalog_for_import();
+      db_mysql_CatalogRef org_cat = createEmptyCatalog();
+      db_mysql_CatalogRef mod_cat = createEmptyCatalog();
 
       {
         std::string org_script;
@@ -1305,7 +1307,7 @@ TEST_FUNCTION(20) {
       options.set("UseFilteredLists", grt::IntegerRef(0));
       options.set("OutputContainer", alter_map);
       options.set("TemplateFile", grt::StringRef(TemplateFile));
-      options.set("UseShortNames", grt::IntegerRef(j));
+      options.set("OmitSchemas", grt::IntegerRef(j));
       options.set("SeparateForeignKeys", grt::IntegerRef(0));
 
       std::string report = diffsql_module->generateReport(org_cat, options, alter_change);
@@ -1372,7 +1374,7 @@ static struct {
   {NULL, NULL, NULL, NULL, NULL}};
 
 TEST_FUNCTION(30) {
-  std::shared_ptr<DiffChange> empty_change;
+  std::shared_ptr<grt::DiffChange> empty_change;
 
   // column insertion
 
@@ -1388,8 +1390,8 @@ TEST_FUNCTION(30) {
   }
 
   MySQLParserServices::Ref services = MySQLParserServices::get();
-  MySQLParserContext::Ref context =
-    services->createParserContext(tester->get_rdbms()->characterSets(), tester->get_rdbms()->version(), false);
+  MySQLParserContext::Ref context = services->createParserContext(tester->get_rdbms()->characterSets(),
+    tester->get_rdbms()->version(), "", false);
 
   grt::DictRef options(true);
   for (int i = 0; neg_data[i].description != NULL; i++) {
@@ -1397,8 +1399,8 @@ TEST_FUNCTION(30) {
     if ((i + 1) % 30 == 0)
       std::cout << std::endl;
 
-    db_mysql_CatalogRef org_cat = create_empty_catalog_for_import();
-    db_mysql_CatalogRef mod_cat = create_empty_catalog_for_import();
+    db_mysql_CatalogRef org_cat= createEmptyCatalog();
+    db_mysql_CatalogRef mod_cat= createEmptyCatalog();
 
     {
       std::string org_script;
