@@ -1,22 +1,27 @@
-# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 from wb import DefineModule
 import grt
+from workbench import db_utils
 
 from workbench.db_utils import MySQLConnection, escape_sql_string, escape_sql_identifier
 
@@ -185,19 +190,32 @@ def getFunctionNames(connection, catalog_name, schema_name):
 def getOS(connection):
     conn = get_connection(connection)
     if conn:
-        result = conn.executeQuery("SELECT @@version_compile_os")
+        try:
+            result = conn.executeQuery("SELECT @@version_compile_os")
+        except db_utils.QueryError as e:
+            grt.send_error("Error executing query: %s." % e)
+            return None
+
         if result and result.nextRow():
             compile_os = result.stringByIndex(1).lower()
             if 'linux' in compile_os:
                 return 'linux'
             elif 'win' in compile_os:
                 return 'windows'
-            elif 'osx' in compile_os:
+            elif any(os in compile_os for os in ['osx', 'macos']):
                 return 'darwin'
 
     return None
 
 
+@ModuleInfo.export(grt.STRING, grt.classes.db_mgmt_Connection)
+def getServerMode(connection):
+    result = execute_query(connection, "SELECT @@SESSION.sql_mode")
+    if result and result.nextRow():
+        return result.stringByIndex(1)
+    return None
+
+
 #########  Reverse Engineering functions #########
 
 
@@ -271,7 +289,7 @@ def reverseEngineer(connection, catalog_name, schemata_list, context):
         return "USE `%s`;\n%s"%(escape_sql_identifier(schema), sql)
 
     def wrap_routine_sql(sql):
-        return "DELIMITER $$\n"+sql
+        return "DELIMITER " + grt.root.wb.options.options['SqlDelimiter'] + "\n" + sql
 
     i = 0.0
     for schema_name in schemata_list:
@@ -279,6 +297,8 @@ def reverseEngineer(connection, catalog_name, schemata_list, context):
         schema.owner = catalog
         schema.name = schema_name
         catalog.schemata.append(schema)
+        context = grt.modules.MySQLParserServices.createNewParserContext(catalog.characterSets, getServerVersion(connection), getServerMode(connection), 1)
+        options = {}
 
         if get_tables or get_views:
             grt.send_info("Reverse engineering tables from %s" % schema_name)
@@ -292,7 +312,7 @@ def reverseEngineer(connection, catalog_name, schemata_list, context):
                     sql = result.stringByIndex(2)
                     grt.push_message_handler(filter_warnings)
                     grt.begin_progress_step(0.1 + 0.9 * (i / total), 0.1 + 0.9 * ((i+0.5) / total))
-                    grt.modules.MysqlSqlFacade.parseSqlScriptString(catalog, wrap_sql(sql, schema_name))
+                    grt.modules.MySQLParserServices.parseSQLIntoCatalogSql(context, catalog, wrap_sql(sql, schema_name), options)
                     grt.end_progress_step()
                     grt.pop_message_handler()
                     i += 0.5
@@ -310,7 +330,7 @@ def reverseEngineer(connection, catalog_name, schemata_list, context):
                 if result and result.nextRow():
                     sql = result.stringByName("SQL Original Statement")
                     grt.begin_progress_step(0.1 + 0.9 * (i / total), 0.1 + 0.9 * ((i+0.5) / total))
-                    grt.modules.MysqlSqlFacade.parseSqlScriptString(catalog, wrap_sql(wrap_routine_sql(sql), schema_name))
+                    grt.modules.MySQLParserServices.parseSQLIntoCatalogSql(context, catalog, wrap_sql(wrap_routine_sql(sql), schema_name), options)
                     grt.end_progress_step()
                     i += 0.5
                 else:
@@ -328,7 +348,7 @@ def reverseEngineer(connection, catalog_name, schemata_list, context):
                 if result and result.nextRow():
                     sql = result.stringByName("Create Procedure")
                     grt.begin_progress_step(0.1 + 0.9 * (i / total), 0.1 + 0.9 * ((i+0.5) / total))
-                    grt.modules.MysqlSqlFacade.parseSqlScriptString(catalog, wrap_sql(wrap_routine_sql(sql), schema_name))
+                    grt.modules.MySQLParserServices.parseSQLIntoCatalogSql(context, catalog, wrap_sql(wrap_routine_sql(sql), schema_name), options)
                     grt.end_progress_step()
                     i += 0.5
                 else:
@@ -344,7 +364,7 @@ def reverseEngineer(connection, catalog_name, schemata_list, context):
                 if result and result.nextRow():
                     sql = result.stringByName("Create Function")
                     grt.begin_progress_step(0.1 + 0.9 * (i / total), 0.1 + 0.9 * ((i+0.5) / total))
-                    grt.modules.MysqlSqlFacade.parseSqlScriptString(catalog, wrap_sql(wrap_routine_sql(sql), schema_name))
+                    grt.modules.MySQLParserServices.parseSQLIntoCatalogSql(context, catalog, wrap_sql(wrap_routine_sql(sql), schema_name), options)
                     grt.end_progress_step()
                     i += 0.5
                 else:
@@ -380,7 +400,9 @@ def reverseEngineerTable(connection, schema_name, table_name):
     result = execute_query(connection, "SHOW CREATE TABLE `%s`.`%s`" % (escape_sql_identifier(schema_name), escape_sql_identifier(table_name)))
     if result and result.nextRow():
         sql = result.stringByIndex(2)
-        grt.modules.MysqlSqlFacade.parseSqlScriptString(catalog, ("USE `%s`;\n" % escape_sql_identifier(schema_name))+sql)
+        context = grt.modules.MySQLParserServices.createNewParserContext(catalog.characterSets, getServerVersion(connection), getServerMode(connection), 1)
+        options = {}
+        grt.modules.MySQLParserServices.parseSQLIntoCatalogSql(context, catalog, ("USE `%s`;\n" % escape_sql_identifier(schema_name)) + sql, options)
     else:
         raise Exception("Could not fetch table information for %s" % table_name)
 
@@ -406,7 +428,9 @@ def reverseEngineerTableToCatalog(connection, catalog, schema_name, table_name):
     result = execute_query(connection, "SHOW CREATE TABLE `%s`.`%s`" % (escape_sql_identifier(schema_name), escape_sql_identifier(table_name)))
     if result and result.nextRow():
         sql = result.stringByIndex(2)
-        grt.modules.MysqlSqlFacade.parseSqlScriptString(catalog, ("USE `%s`;\n" % escape_sql_identifier(schema_name))+sql)
+        context = grt.modules.MySQLParserServices.createNewParserContext(catalog.characterSets, getServerVersion(connection), getServerMode(connection), 1)
+        options = {}
+        grt.modules.MySQLParserServices.parseSQLIntoCatalogSql(context, catalog, ("USE `%s`;\n" % escape_sql_identifier(schema_name))+sql, options)
     else:
         raise Exception("Could not fetch table information for %s" % table_name)
 
