@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "testgrt.h"
@@ -30,13 +34,13 @@
 
 #include "grtsqlparser/mysql_parser_services.h"
 
-BEGIN_TEST_DATA_CLASS(sql_create)
+BEGIN_TEST_DATA_CLASS(sql_create_test)
 protected:
 WBTester *tester;
 SQLGeneratorInterfaceImpl *diffsql_module;
 sql::ConnectionWrapper connection;
 
-TEST_DATA_CONSTRUCTOR(sql_create) {
+TEST_DATA_CONSTRUCTOR(sql_create_test) {
   tester = new WBTester;
   diffsql_module = NULL;
 
@@ -51,15 +55,15 @@ TEST_DATA_CONSTRUCTOR(sql_create) {
   connection = tester->create_connection_for_import();
 }
 
-TEST_DATA_DESTRUCTOR(sql_create) {
+TEST_DATA_DESTRUCTOR(sql_create_test) {
   std::auto_ptr<sql::Statement> stmt(connection->createStatement());
-  std::string script = "DROP SCHEMA IF EXISTS `A` ; DROP SCHEMA IF EXISTS `B` ;";
-  execute_script(stmt.get(), script);
+  stmt->execute("DROP SCHEMA IF EXISTS `A`;");
+  stmt->execute("DROP SCHEMA IF EXISTS `B`;");
 }
 
 END_TEST_DATA_CLASS
 
-TEST_MODULE(sql_create, "sql create");
+TEST_MODULE(sql_create_test, "sql create");
 
 // Test if sql generated for synthetic model is valid.
 TEST_FUNCTION(10) {
@@ -103,6 +107,7 @@ TEST_FUNCTION(10) {
   std::string export_sql_script = options.get_string("OutputScript");
   ensure("DROP TABLE missing in generated sql",
          export_sql_script.find("DROP TABLE IF EXISTS `test_schema`.`t1`") != std::string::npos);
+
   execute_script(stmt.get(), export_sql_script);
 }
 
@@ -129,7 +134,7 @@ TEST_FUNCTION(20) {
   options.set("OutputContainer", create_map);
   options.set("CaseSensitive", grt::IntegerRef(omf.case_sensitive));
   options.set("GenerateSchemaDrops", grt::IntegerRef(1));
-  options.set("UseShortNames", grt::IntegerRef(1));
+  options.set("OmitSchemas", grt::IntegerRef(1));
   options.set("GenerateUse", grt::IntegerRef(1));
   options.set("GenerateDrops", grt::IntegerRef(1));
   diffsql_module->generateSQL(catalog, options, create_change);
@@ -165,7 +170,7 @@ TEST_FUNCTION(30) {
   options.set("OutputContainer", create_map);
   options.set("CaseSensitive", grt::IntegerRef(omf.case_sensitive));
   options.set("GenerateSchemaDrops", grt::IntegerRef(1));
-  options.set("UseShortNames", grt::IntegerRef(1));
+  options.set("OmitSchemas", grt::IntegerRef(1));
   options.set("GenerateUse", grt::IntegerRef(1));
   options.set("GenerateDrops", grt::IntegerRef(1));
   diffsql_module->generateSQL(catalog, options, create_change);
@@ -252,6 +257,8 @@ TEST_FUNCTION(50) {
 
   // before 5.5.3, column comments <= 255, table <= 60
   {
+    grt::DictRef dbsett(diffsql_module->getTraitsForServerVersion(5, 5, 2));
+    dbsett.set("CaseSensitive", grt::IntegerRef(omf.case_sensitive));
     table->comment(comment_60);
     table->columns()[1]->comment(comment_255);
     std::shared_ptr<DiffChange> create_change = diff_make(e, catalog, &omf);
@@ -264,6 +271,7 @@ TEST_FUNCTION(50) {
     options.set("CaseSensitive", grt::IntegerRef(omf.case_sensitive));
     options.set("GenerateSchemaDrops", grt::IntegerRef(1));
     options.set("GenerateDrops", grt::IntegerRef(1));
+    options.set("DBSettings", dbsett);
     diffsql_module->generateSQL(catalog, options, create_change);
 
     std::string s = create_map.get_string("db.mysql.Table::`test_schema`.`t1`::t1");
@@ -274,6 +282,8 @@ TEST_FUNCTION(50) {
   }
 
   {
+    grt::DictRef dbsett(diffsql_module->getTraitsForServerVersion(5, 5, 2));
+    dbsett.set("CaseSensitive", grt::IntegerRef(omf.case_sensitive));
     table->comment(comment_60 + "###");
     table->columns()[1]->comment(comment_255 + "###");
     std::shared_ptr<DiffChange> create_change = diff_make(e, catalog, &omf);
@@ -286,6 +296,7 @@ TEST_FUNCTION(50) {
     options.set("CaseSensitive", grt::IntegerRef(omf.case_sensitive));
     options.set("GenerateSchemaDrops", grt::IntegerRef(1));
     options.set("GenerateDrops", grt::IntegerRef(1));
+    options.set("DBSettings", dbsett);
     diffsql_module->generateSQL(catalog, options, create_change);
 
     std::string s = create_map.get_string("db.mysql.Table::`test_schema`.`t1`::t1");
@@ -375,7 +386,7 @@ TEST_FUNCTION(60) {
     options.set("OutputContainer", create_map);
     options.set("CaseSensitive", grt::IntegerRef(1));
     options.set("GenerateSchemaDrops", grt::IntegerRef(1));
-    options.set("UseShortNames", grt::IntegerRef(1));
+    options.set("OmitSchemas", grt::IntegerRef(1));
     options.set("GenerateUse", grt::IntegerRef(1));
     options.set("GenerateDrops", grt::IntegerRef(1));
     options.set("GenerateDocumentProperties", grt::IntegerRef(0));
@@ -437,7 +448,7 @@ TEST_FUNCTION(60) {
     options.set("OutputContainer", create_map);
     options.set("CaseSensitive", grt::IntegerRef(1));
     options.set("GenerateSchemaDrops", grt::IntegerRef(1));
-    options.set("UseShortNames", grt::IntegerRef(1));
+    options.set("OmitSchemas", grt::IntegerRef(1));
     options.set("GenerateUse", grt::IntegerRef(1));
     options.set("GenerateDrops", grt::IntegerRef(1));
     options.set("GenerateDocumentProperties", grt::IntegerRef(0));
@@ -489,10 +500,10 @@ TEST_FUNCTION(70) {
 
   catalog->schemata()[0]->name("sakila_test");
 
-  parser::MySQLParserServices::Ref services = parser::MySQLParserServices::get();
+  parsers::MySQLParserServices::Ref services = parsers::MySQLParserServices::get();
   GrtVersionRef version = bec::parse_version("5.6.0");
-  parser::MySQLParserContext::Ref context =
-    services->createParserContext(tester->get_rdbms()->characterSets(), version, false);
+  parsers::MySQLParserContext::Ref context =
+    services->createParserContext(tester->get_rdbms()->characterSets(), version, "", false);
   services->renameSchemaReferences(context, catalog, "sakila", "sakila_test");
 
   cmp.init_omf(&omf);
@@ -508,6 +519,9 @@ TEST_FUNCTION(70) {
 
   create_map = diffsql_module->generateSQLForDifferences(GrtNamedObjectRef(), catalog, options);
 
+  grt::DictRef dbsett(diffsql_module->getTraitsForServerVersion(5, 6, 0));
+  dbsett.set("CaseSensitive", grt::IntegerRef(omf.case_sensitive));
+  options.set("DBSettings", dbsett);
   diffsql_module->makeSQLExportScript(catalog, options, create_map, drop_map);
 
   std::string export_sql_script = options.get_string("OutputScriptHeader") + options.get_string("OutputScript");
@@ -543,4 +557,4 @@ TEST_FUNCTION(99) {
   delete tester;
 }
 
-END_TESTS
+END_TESTS 
