@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include <ostream>
@@ -28,6 +32,8 @@
 #include "base/string_utilities.h"
 #include "db.mysql/src/module_db_mysql.h"
 #include "base/log.h"
+#include "grtsqlparser/mysql_parser_services.h"
+#include "base/util_functions.h"
 
 #include <glib.h>
 
@@ -173,6 +179,16 @@ void Db_plugin::load_schemata(std::vector<std::string> &schemata) {
   DbMySQLImpl *diffsql_module = grt::GRT::get()->find_native_module<DbMySQLImpl>("DbMySQL");
   _db_options = diffsql_module->getTraitsForServerVersion(major, minor, revision);
   _db_options.set("CaseSensitive", grt::IntegerRef(dbc_meta->storesMixedCaseIdentifiers()));
+  _db_options.set("MySQLVersion", grt::StringRef(base::strfmt("%d.%d.%d", major, minor, revision)));
+
+  const std::unique_ptr<sql::Statement> statement(dbc_conn->createStatement());
+  const std::unique_ptr<sql::ResultSet> rs(statement->executeQuery("SHOW SESSION VARIABLES LIKE 'sql_mode'"));
+  if (rs->next()) {
+    _db_options.set("SqlMode", grt::StringRef(rs->getString(2)));
+  } else {
+    _db_options.set("SqlMode", grt::StringRef());
+  }
+
 
   std::auto_ptr<sql::ResultSet> rset(dbc_meta->getSchemaObjects("", "", "schema"));
   _schemata.reserve(rset->rowsCount());
@@ -469,16 +485,29 @@ db_CatalogRef Db_plugin::db_catalog() {
   std::string sql_input_script;
   dump_ddl(sql_input_script);
 
-  db_CatalogRef catalog = grt::GRT::get()->create_object<db_Catalog>(mod_cat.get_metaclass()->name());
-  catalog->version(pm->rdbms()->version());
+  db_mysql_CatalogRef catalog = grt::GRT::get()->create_object<db_mysql_Catalog>(mod_cat.get_metaclass()->name());
+
+
   grt::replace_contents(catalog->simpleDatatypes(), pm->rdbms()->simpleDatatypes());
   catalog->name("default");
   catalog->oldName(catalog->name());
 
-  SqlFacade::Ref sql_parser = SqlFacade::instance_for_rdbms(pm->rdbms());
   grt::DictRef parse_options(true);
   parse_options.set("case_sensitive_identifiers", _db_options.get("CaseSensitive", grt::IntegerRef(1)));
-  sql_parser->parseSqlScriptStringEx(catalog, sql_input_script, parse_options);
+
+  grt::StringRef sqlMode = grt::StringRef::cast_from(_db_options.get("SqlMode", grt::StringRef("")));
+
+  auto version = bec::parse_version(grt::StringRef::cast_from(_db_options.get("MySQLVersion", grt::StringRef(base::getVersion()))).c_str());
+  catalog->version(version);
+
+  auto services = parsers::MySQLParserServices::get();
+  auto context = services->createParserContext(pm->rdbms()->characterSets(), version, sqlMode.c_str(),
+    _db_options.get_int("CaseSensitive", 1) != 0);
+  auto errorCount = services->parseSQLIntoCatalog(context, catalog, sql_input_script, parse_options);
+
+  if (errorCount != 0) {
+    logError("There was an error while parsing the DDL retrieved from the server.\n");
+  }
 
   return catalog;
 }
