@@ -1,19 +1,23 @@
-# Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 """
 How to handle MySQL logs
@@ -167,9 +171,9 @@ Use cases for the server logs
    session or until the user clicks on the tab's *Close* button.
 """
 
-from mforms import newBox, newLabel, newTreeNodeView, newTabView, newButton
+import grt
+from mforms import newBox, newLabel, newTreeView, newTabView, newButton
 import mforms
-from wb_admin_utils import not_running_warning_label, make_panel_header
 from wb_log_reader import GeneralQueryLogReader, SlowQueryLogReader, GeneralLogFileReader, SlowLogFileReader, ErrorLogFileReader
 import wb_admin_config_file_be
 
@@ -178,6 +182,9 @@ from workbench.utils import WorkerThreadHelper
 
 from workbench.log import log_error, log_debug
 
+from wb_admin_utils import WbAdminTabBase, WbAdminValidationConfigFile, WbAdminValidationConnection, WbAdminValidationBase
+
+
 class LogView(mforms.Box):
     '''
     Main front end view class for displaying log entries.
@@ -216,15 +223,21 @@ class LogView(mforms.Box):
         self.error_box = newBox(True)
         self.error_box.set_spacing(8)
         error_label = newLabel(str(error))
-        self.error_box.add(error_label, False, False)
+        self.error_box.add(error_label, False, True)
         try_again_button = newButton()
         try_again_button.set_text('Try again')
-        self.error_box.add(try_again_button, False, False)
-        try_again_button.add_clicked_callback(self.update_ui)
+        self.error_box.add(try_again_button, False, True)
+        try_again_button.add_clicked_callback(self.try_again)
         self.add(self.error_box, False, True)
 
+    def try_again(self):
+        self.update_ui()
+        self.refresh()
+
+    def create_filter_box(self):
+        pass
+
     def update_ui(self):
-        # Clean up:
         if self.error_box:
             self.remove(self.error_box)
             self.error_box = None
@@ -243,22 +256,29 @@ class LogView(mforms.Box):
 
         self.set_padding(8)
         self.set_spacing(8)
-
+        
+        filter_box = self.create_filter_box()
+        if filter_box:
+            if filter_box.get_parent():
+                self.remove(filter_box)
+            self.add(filter_box, False, True)
+        
         try:
             self.log_reader = self.BackendLogReaderClass(*self.args)
         except Exception, error:
-            log_error("Exception creating log reader: %s\n" % error)
-            self._show_error("Unexpected error creating log reader: %s\n" % error)
+            import traceback
+            log_error("Exception creating log reader: %s\n%s\n" % (error, traceback.format_exc()))
+            self._show_error("Error creating log reader: %s\n" % error)
             return
 
         if self.log_reader.partial_support:
             self.warning_box = newBox(True)
             self.warning_box.set_spacing(8)
             warning_label = newLabel(self.log_reader.partial_support)
-            self.warning_box.add(warning_label, False, False)
+            self.warning_box.add(warning_label, False, True)
             self.add(self.warning_box, False, True)
 
-        self.tree = newTreeNodeView(mforms.TreeFlatList)
+        self.tree = newTreeView(mforms.TreeFlatList)
         self.tree.set_selection_mode(mforms.TreeSelectMultiple)
 
         for colspec in self.log_reader.column_specs:
@@ -278,21 +298,28 @@ class LogView(mforms.Box):
 
         table.add(newLabel("Log File Location:"), 0, 1, 0, 1, mforms.HFillFlag)
         if self.log_reader.log_file:
-            label = newLabel(self.log_reader.log_file.path)
+            if self.log_reader.log_file.path == "stderr":
+                self.query = """<QueryList><Query Id = "0" Path = "Application">
+                                <Select Path = "Application">*[System[Provider[@Name = 'MySQL'] and TimeCreated[timediff(@SystemTime) &lt;= 604800000]]]</Select>
+                                </Query></QueryList>"""
+                grt.setEventlogCallback(self.printResults)
+                label = newLabel("Windows Event viewer")
+            else:
+                label = newLabel(self.log_reader.log_file.path)
         else:
             label = newLabel("TABLE")
         label.set_style(mforms.BoldStyle)
-        table.add(label, 1, 2, 0, 1, mforms.HFillFlag|mforms.HExpandFlag)
+        table.add(label, 1, 2, 0, 1, mforms.VFillFlag|mforms.HFillFlag|mforms.HExpandFlag)
 
-        table.add(newLabel("Log File Size:"), 2, 3, 0, 1, mforms.HFillFlag)
+        table.add(newLabel("Log File Size:"), 2, 3, 0, 1, mforms.VFillFlag|mforms.HFillFlag)
         self.size_label = newLabel("retrieving..." if self.log_reader.log_file else "-")
         self.size_label.set_style(mforms.BoldStyle)
-        table.add(self.size_label, 3, 4, 0, 1, mforms.HFillFlag|mforms.HExpandFlag)
+        table.add(self.size_label, 3, 4, 0, 1, mforms.VFillFlag|mforms.HFillFlag|mforms.HExpandFlag)
 
-        table.add(newLabel("Showing:"), 0, 1, 1, 2, mforms.HFillFlag)
+        table.add(newLabel("Showing:"), 0, 1, 1, 2, mforms.VFillFlag|mforms.HFillFlag)
         self.range_label = newLabel("retrieving data...")
         self.range_label.set_style(mforms.BoldStyle)
-        table.add(self.range_label, 1, 2, 1, 2, mforms.HFillFlag)
+        table.add(self.range_label, 1, 2, 1, 2, mforms.VFillFlag|mforms.HFillFlag)
         self.add(table, False, True)
 
         self.bbox = newBox(True)
@@ -300,8 +327,8 @@ class LogView(mforms.Box):
         self.add_end(self.bbox, False, True)
 
         self._menu = mforms.newContextMenu()
-        self._menu.add_item_with_title("Copy", self.copy_record, "copy_record")
-        self._menu.add_item_with_title("Copy Details", self.copy_details, "copy_details")
+        self._menu.add_item_with_title("Copy Row", self.copy_record, "Copy Record", "Copy Record")
+        self._menu.add_item_with_title("Copy Details", self.copy_details, "Copy Details", "Copy Details")
         self.tree.set_context_menu(self._menu)
 
         self.bbox.add(newLabel(""), True, True)
@@ -331,15 +358,39 @@ class LogView(mforms.Box):
         self.bbox.add(self.refresh_button, False, True)
         self.refresh_button.add_clicked_callback(self.refresh)
 
+        if self.log_reader.log_file and self.log_reader.log_file.path == "stderr":
+            self.actual_position = 0
+            grt.getEventLogEntry(0, self.query)
+
+    def printResults(self, text, args):
+        self.actual_position = self.actual_position + 1
+        row = self.tree.add_node()
+        self.size_label.set_text(str(self.actual_position))
+        for idx, key in enumerate(self.log_reader.column_keys):
+            row.set_string(idx, args[key])
+
     def read_data_worker(self, out):
         out(self.log_reader.current())
 
     def handle_worker_data(self, data):
+        if isinstance(data, Exception):
+            mforms.Utilities.show_error("Error Reading Log File",
+                                        "%s" % data, "OK", "", "")
+            self.worker = None            
+            return
         self.refresh(data)
         self.worker = None
 
     def refresh(self, records=None):
         if self.log_reader:
+            if self.log_reader.log_file and self.log_reader.log_file.path == "stderr":
+                grt.getEventLogEntry(self.actual_position, self.query)
+                self.bof_button.set_enabled(False)
+                self.back_button.set_enabled(False)
+                self.eof_button.set_enabled(False)
+                self.next_button.set_enabled(False)
+                self.range_label.set_text('Records read: %d' % self.actual_position)
+                return
             try:
                 self.log_reader.refresh()
 
@@ -370,6 +421,14 @@ class LogView(mforms.Box):
             except (ServerIOError, RuntimeError, LogFileAccessError, OperationCancelledError, InvalidPasswordError, IOError, ValueError), error:
                 self._show_error(error)
 
+    def copy_details(self):
+        selection = self.tree.get_selection()
+        text = []
+        for node in selection:
+            text.append(node.get_string(self.log_reader.detail_column))
+        if text:
+            mforms.Utilities.set_clipboard_text("\n".join(text))
+
     def copy_record(self):
         selection = self.tree.get_selection()
         text = [", ".join([r[0] for r in self.log_reader.column_specs])]
@@ -381,15 +440,6 @@ class LogView(mforms.Box):
         if text:
             mforms.Utilities.set_clipboard_text("\n".join(text))
 
-    def copy_details(self):
-        selection = self.tree.get_selection()
-        text = []
-        for node in selection:
-            text.append(node.get_string(self.log_reader.detail_column))
-        if text:
-            mforms.Utilities.set_clipboard_text("\n".join(text))
-
-
     def go_bof(self):
         try:
             self.refresh(self.log_reader.first())
@@ -417,44 +467,102 @@ class LogView(mforms.Box):
             self._show_error(error)
 
 
-class WbAdminLogs(mforms.Box):
+class LogViewGeneric(LogView):
+    def __init__(self, owner, BackendLogReaderClass, *args):
+        self.filter_list = {}
+        self.filter_box = mforms.newBox(True)
+        self.filter_text = ""
+
+        super(LogViewGeneric, self).__init__(owner, BackendLogReaderClass, *args)
+
+    def add_filter_option(self, text):
+        filter = mforms.newRadioButton(1)
+        filter.set_text(text)
+        filter.add_clicked_callback(self.filter_handler)
+        
+        self.filter_list[text] = filter
+        self.filter_box.add(filter, False, True)
+        
+    def create_filter_box(self):
+        self.add_filter_option("All")
+        self.add_filter_option("InnoDB")
+        # so that it shows up in 'development' and 'Commercial'
+        if not grt.root.wb.info.edition == "Community":
+            self.add_filter_option("Firewall")
+        return self.filter_box
+    
+    def filter_handler(self):
+        for text, filter in self.filter_list.iteritems():
+            if filter.get_active():
+                self.filter_text = text
+
+        self.refresh(None)
+
+    def refresh(self, records=None):
+        filtered_records = None
+        if records:
+            filtered_records = []
+            for record in records:
+                text = record[3]
+                if self.filter_text == "All" or text.lower().find(self.filter_text.lower()) >= 0:
+                    filtered_records.append(record)
+        super(LogViewGeneric, self).refresh(filtered_records)
+
+
+class WbAdminValidationLogOutputType(WbAdminValidationBase):
+    def __init__(self, instance_info):
+        WbAdminValidationBase.__init__(self)
+        self._instance_info = instance_info
+        
+        self.set_error_message("""A problem was detected in your current log destination.
+It is set to %s. Please refer to the documentation for further information:
+https://dev.mysql.com/doc/en/log-destinations.html""" % self._instance_info.log_output)
+        
+    def validate(self):
+        return self._instance_info.log_output == "FILE" or self._instance_info.log_output == "TABLE" or self._instance_info.log_output == "FILE,TABLE" or self._instance_info.log_output == "TABLE,FILE" or not self._instance_info.log_output
+
+
+class WbAdminLogs(WbAdminTabBase):
     ui_created = False
 
     @classmethod
     def wba_register(cls, admin_context):
-        admin_context.register_page(cls, "wba_instance", "Server Logs", True)
+        admin_context.register_page(cls, "Instance", "Server Logs", "Server Logs", True)
 
     @classmethod
     def identifier(cls):
         return "admin_server_logs"
+    
+    def shutdown(self):
+        self.general_file_log_tab = None
+        self.slow_file_log_tab = None
+        self.error_file_log_tab = None
 
-    def __init__(self, ctrl_be, server_profile, main_view):
-        super(WbAdminLogs, self).__init__(False)
-        self.set_managed()
-        self.ctrl_be = ctrl_be
-        self.server_profile = server_profile
-        self.main_view = main_view
+    def __init__(self, ctrl_be, instance_info, main_view):
+        WbAdminTabBase.__init__(self, ctrl_be, instance_info, main_view)
         self.disable_log_refresh = False
+        
+        self.add_validation(WbAdminValidationConnection(ctrl_be))
+        self.add_validation(WbAdminValidationConfigFile(instance_info))
+        self.add_validation(WbAdminValidationLogOutputType(instance_info))
+        
+        self.set_standard_header("title_logs.png", self.instance_info.name, "Server Logs")
+        
 
     def create_ui(self):
-        self.set_padding(12)
-        self.set_spacing(8)
-
-        self.heading = make_panel_header("title_logs.png", self.server_profile.name, "Server Logs")
-        self.add(self.heading, False, True)
-
-        self.warning = not_running_warning_label()
-        self.add(self.warning, False, True)
-        self.warning.show(False)
+        self.detect_paths()
 
         self.tabView = newTabView(False)
-        self.add(self.tabView, True, True)
 
         self.general_log_tab = None
         self.slow_log_tab = None
         self.general_file_log_tab = None
         self.slow_file_log_tab = None
         self.error_file_log_tab = None
+        
+        self.update_ui()
+        
+        return self.tabView
 
     def get_log_destination(self):
         dest = {}
@@ -466,8 +574,8 @@ class WbAdminLogs(mforms.Box):
                         return dest
                 except:
                     return dest
-                self.server_profile.log_output = 'FILE' if result.stringByName("Value")=='ON' else 'NONE'
-                log_debug('%s: log_output = %s\n' % (self.__class__.__name__, self.server_profile.log_output) )
+                self.instance_info.log_output = 'FILE' if result.stringByName("Value")=='ON' else 'NONE'
+                log_debug('%s: log_output = %s\n' % (self.__class__.__name__, self.instance_info.log_output) )
             else:
                 try:
                     result = self.ctrl_be.exec_query("SHOW VARIABLES LIKE 'log_output'")
@@ -475,20 +583,25 @@ class WbAdminLogs(mforms.Box):
                         return dest
                 except:
                     return dest
-                self.server_profile.log_output = result.stringByName("Value")
+                self.instance_info.log_output = result.stringByName("Value")
 
-                if 'FILE' in self.server_profile.log_output and 'TABLE' in self.server_profile.log_output:
+                if 'FILE' in self.instance_info.log_output and 'TABLE' in self.instance_info.log_output:
                     def open_remote_file(path):
-                        import wb_admin_ssh, wb_server_control
-                        ssh = wb_admin_ssh.WbAdminSSH()
-                        ssh.wrapped_connect(self.server_profile, wb_server_control.PasswordHandler(self.server_profile))
-                        sftp = ssh.client.open_sftp()
-                        if not ssh.is_connected():
-                            raise IOError, ''
-                        sftp.open(path)
+                        import wb_server_control
+                        
+                        try:
+                            ssh = self.ctrl_be.ssh.WbAdminSSH()
+                            ssh.wrapped_connect(self.server_profile, wb_server_control.PasswordHandler(self.server_profile))
+                            if ssh.isConnected() == 1:
+                                ssh.open(path)
+                                ssh.close()
+                            return True
+                        except Exception:
+                            log_error("Error opening remote file: %s\n", path)
+                            return False
 
                     # Can't read logs from files if admin is disabled:
-                    if not self.server_profile.admin_enabled:
+                    if not self.instance_info.admin_enabled:
                         dest['general_log'] = 'TABLE'
                         dest['slow_log'] = 'TABLE'
                         log_debug('%s: log_output = %s\n' % (self.__class__.__name__, dest) )
@@ -496,9 +609,9 @@ class WbAdminLogs(mforms.Box):
 
                     # Try to prioritize the files if they are readable
                     if not getattr(self, 'stored_general_log_source_choice', None):
-                        if self.server_profile.general_log_file_path:
+                        if self.instance_info.general_log_file_path:
                             try:
-                                open(self.server_profile.general_log_file_path) if self.server_profile.is_local else open_remote_file(self.server_profile.general_log_file_path)
+                                open(self.instance_info.general_log_file_path) if self.instance_info.is_local else open_remote_file(self.instance_info.general_log_file_path)
                                 dest['general_log'] = 'FILE'
                             except:
                                 dest['general_log'] = 'TABLE'
@@ -509,9 +622,9 @@ class WbAdminLogs(mforms.Box):
                         dest['general_log'] = self.stored_general_log_source_choice
 
                     if not getattr(self, 'stored_slow_log_source_choice', None):
-                        if self.server_profile.slow_log_file_path:
+                        if self.instance_info.slow_log_file_path:
                             try:
-                                open(self.server_profile.slow_log_file_path) if self.server_profile.is_local else open_remote_file(self.server_profile.slow_log_file_path)
+                                open(self.instance_info.slow_log_file_path) if self.instance_info.is_local else open_remote_file(self.instance_info.slow_log_file_path)
                                 dest['slow_log'] = 'FILE'
                             except:
                                 dest['slow_log'] = 'TABLE'
@@ -558,36 +671,36 @@ class WbAdminLogs(mforms.Box):
         if 'FILE' in source:
             source = list(source) + ['general_file_tab', 'slow_file_tab']
 
-        if 'error_file_tab' in source and self.server_profile.error_log_file_path and not self.error_file_log_tab:
+        if 'error_file_tab' in source and self.instance_info.error_log_file_path and not self.error_file_log_tab:
             try:
-                self.error_file_log_tab = LogView(self, ErrorLogFileReader, self.ctrl_be, self.server_profile.error_log_file_path)
+                self.error_file_log_tab = LogViewGeneric(self, ErrorLogFileReader, self.ctrl_be, self.instance_info.error_log_file_path)
                 self.tabView.add_page(self.error_file_log_tab, "Error Log File")
             except IOError:
-                self.show_message_panel('There was a problem reading %s. Please verify that you have read permissions on that file' % self.server_profile.error_log_file_path)
+                self.show_message_panel('There was a problem reading %s. Please verify that you have read permissions on that file' % self.instance_info.error_log_file_path)
                 self.error_file_log_tab = None
 
-        if 'general_file_tab' in source and self.server_profile.general_log_enabled and self.server_profile.general_log_file_path and not self.general_file_log_tab:
+        if 'general_file_tab' in source and self.instance_info.general_log_enabled and self.instance_info.general_log_file_path and not self.general_file_log_tab:
             try:
-                self.general_file_log_tab = LogView(self, GeneralLogFileReader, self.ctrl_be, self.server_profile.general_log_file_path)
+                self.general_file_log_tab = LogView(self, GeneralLogFileReader, self.ctrl_be, self.instance_info.general_log_file_path)
                 self.tabView.add_page(self.general_file_log_tab, "General Log File")
             except IOError:
-                self.show_message_panel('There was a problem reading %s.\nPlease verify that you have read permissions on that file' % self.server_profile.general_log_file_path)
+                self.show_message_panel('There was a problem reading %s.\nPlease verify that you have read permissions on that file' % self.instance_info.general_log_file_path)
                 self.general_file_log_tab = None
 
 
-        if 'slow_file_tab' in source and self.server_profile.slow_log_enabled and self.server_profile.slow_log_file_path and not self.slow_file_log_tab:
+        if 'slow_file_tab' in source and self.instance_info.slow_log_enabled and self.instance_info.slow_log_file_path and not self.slow_file_log_tab:
             try:
-                self.slow_file_log_tab = LogView(self, SlowLogFileReader, self.ctrl_be, self.server_profile.slow_log_file_path)
+                self.slow_file_log_tab = LogView(self, SlowLogFileReader, self.ctrl_be, self.instance_info.slow_log_file_path)
                 self.tabView.add_page(self.slow_file_log_tab, "Slow Log File")
             except IOError:
-                self.show_message_panel('There was a problem reading %s. Please verify that you have read permissions on that file' % self.server_profile.slow_log_file_path)
+                self.show_message_panel('There was a problem reading %s. Please verify that you have read permissions on that file' % self.instance_info.slow_log_file_path)
                 self.slow_file_log_tab = None
 
-        if 'general_tab' in source and self.server_profile.general_log_enabled and not self.general_log_tab:
+        if 'general_tab' in source and self.instance_info.general_log_enabled and not self.general_log_tab:
             self.general_log_tab = LogView(self, GeneralQueryLogReader, self.ctrl_be)
             self.tabView.add_page(self.general_log_tab, 'General Log Table')
 
-        if 'slow_tab' in source and self.server_profile.slow_log_enabled and not self.slow_log_tab:
+        if 'slow_tab' in source and self.instance_info.slow_log_enabled and not self.slow_log_tab:
             self.slow_log_tab = LogView(self, SlowQueryLogReader, self.ctrl_be)
             self.tabView.add_page(self.slow_log_tab, 'Slow Query Log Table')
 
@@ -595,22 +708,22 @@ class WbAdminLogs(mforms.Box):
         dest = self.get_log_destination()
 
         self._add_tabs('error_file_tab')
+        
+        if not self.instance_info.log_output:
+            self.instance_info.log_output = 'TABLE,FILE'
 
-        if not self.server_profile.log_output:
-            self.server_profile.log_output = 'TABLE,FILE'
-
-        if 'NONE' in self.server_profile.log_output:
+        if 'NONE' in self.instance_info.log_output:
             self._remove_tabs('TABLE', 'FILE')
 
-        elif self.server_profile.log_output == 'FILE':
+        elif self.instance_info.log_output == 'FILE':
             self._remove_tabs('TABLE')
             self._add_tabs('FILE')
 
-        elif self.server_profile.log_output == 'TABLE':
+        elif self.instance_info.log_output == 'TABLE':
             self._remove_tabs('FILE')
             self._add_tabs('TABLE')
 
-        elif self.server_profile.log_output == 'TABLE,FILE' or self.server_profile.log_output == 'FILE,TABLE':
+        elif self.instance_info.log_output == 'TABLE,FILE' or self.instance_info.log_output == 'FILE,TABLE':
             tabs = set(['general_tab', 'slow_tab', 'general_file_tab', 'slow_file_tab'])
             to_be_added = []
             if not self.ctrl_be.is_sql_connected():
@@ -621,60 +734,45 @@ class WbAdminLogs(mforms.Box):
             self._remove_tabs( *tuple(tabs - set(to_be_added)) )  # Remove the ones that aren't added
             self._add_tabs( *tuple(to_be_added) )
 
-        else:
-            msg = """We have detected a problem in your current Log Destination.
-It is set to %s. Please refer to the documentation for further information:
-http://dev.mysql.com/doc/refman/5.1/en/log-destinations.html""" % self.server_profile.log_output
-            self.show_message_panel(msg)
-            return
-
-        self.warning.show(False)
         self.tabView.show(True)
-
-    def page_activated(self):
-        if not self.ui_created:
-            self.detect_paths()
-            self.create_ui()
-            self.ui_created = True
-
-        self.update_ui()
+        
         try:
             self.refresh()
         except Exception, e:
             r = mforms.Utilities.show_warning("Log Refresh", "An error occurred while displaying MySQL server logs: %s" % e, "Ignore", "Cancel", "")
             if r == mforms.ResultCancel:
-                self.disable_log_refresh = True
+                self.disable_log_refresh = True        
 
     def detect_paths(self):
         # Retrieve from server the log file paths if exist
         status = self.ctrl_be.is_server_running(verbose=0)
         if status in ['stopped', 'unknown'] and not all(
-                [ self.server_profile.general_log_file_path,  # only proceed to parse the config file if
-                  self.server_profile.slow_log_file_path,     # any of these is missing
-                  self.server_profile.error_log_file_path,
-                  self.server_profile.log_output ] ):
+                [ self.instance_info.general_log_file_path,  # only proceed to parse the config file if
+                  self.instance_info.slow_log_file_path,     # any of these is missing
+                  self.instance_info.error_log_file_path,
+                  self.instance_info.log_output ] ):
 
-            cfg_be = wb_admin_config_file_be.WbAdminConfigFileBE(self.server_profile, self.ctrl_be)
-            cfg_be.open_configuration_file(self.server_profile.config_file_path, warn_missing=False)
-            options = dict(cfg_be.get_options(self.server_profile.config_file_section))
+            cfg_be = wb_admin_config_file_be.WbAdminConfigFileBE(self.instance_info, self.ctrl_be)
+            cfg_be.open_configuration_file(self.instance_info.config_file_path, warn_missing=False)
+            options = dict(cfg_be.get_options(self.instance_info.config_file_section))
 
-            if not self.server_profile.log_output and options.has_key('log-output'):
-                self.server_profile.log_ouput = options['log-output']
+            if not self.instance_info.log_output and options.has_key('log-output'):
+                self.instance_info.log_ouput = options['log-output']
 
-            if not self.server_profile.general_log_file_path:
+            if not self.instance_info.general_log_file_path:
                 path = options['general_log_file'] if options.has_key('general_log_file') else (
                        options['log'] if options.has_key('log') else '')  # the 'log' option is deprecated but still allowed
                 if path:
-                    self.server_profile.general_log_file_path = path.strip('"')
+                    self.instance_info.general_log_file_path = path.strip('"')
 
-            if not self.server_profile.slow_log_file_path:
+            if not self.instance_info.slow_log_file_path:
                 path = options['slow_query_log_file'] if options.has_key('slow_query_log_file') else (
                        options['log-slow-queries'] if options.has_key('log-slow-queries') else '')  # the 'log-slow-queries' option is deprecated but still allowed
                 if path:
-                    self.server_profile.slow_log_file_path = path.strip('"')
+                    self.instance_info.slow_log_file_path = path.strip('"')
 
-            if not self.server_profile.error_log_file_path and options.has_key('log-error'):
-                self.server_profile.error_log_file_path = options['log-error'].strip('"')
+            if not self.instance_info.error_log_file_path and options.has_key('log-error'):
+                self.instance_info.error_log_file_path = options['log-error'].strip('"')
 
 
     def refresh(self):
