@@ -8,9 +8,9 @@ using System.Runtime.InteropServices;
 [assembly: AssemblyTitle("WBPluginPrinting")]
 [assembly: AssemblyDescription("")]
 [assembly: AssemblyConfiguration("")]
-[assembly: AssemblyCompany("-")]
+[assembly: AssemblyCompany("Oracle Corporation")]
 [assembly: AssemblyProduct("WBPluginPrinting")]
-[assembly: AssemblyCopyright("Copyright © 2007, 2014, Oracle")]
+[assembly: AssemblyCopyright("Copyright (c) 2007, 2016, Oracle and/or its affiliates")]
 [assembly: AssemblyTrademark("")]
 [assembly: AssemblyCulture("")]
 
