@@ -1,29 +1,33 @@
-# Copyright (c) 2013, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2015, 2018, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
-
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 import re
 import grt
 import mforms
-from workbench.db_utils import escape_sql_identifier, escape_sql_string as esc_str
+from workbench.db_utils import escape_sql_identifier
 from workbench.plugins import insert_item_to_plugin_context_menu
 
 from table_templates import TableTemplateManager
 
+from sqlide_tableman_ext import CreateIndexForm
 from sqlide_catalogman_ext import show_schema_manager
 
 def esc_ident(s):
@@ -36,7 +40,7 @@ def esc_ident(s):
 def _(s):
     return s
 
-
+template_manager = None
 def init():
     global template_manager
 
@@ -132,15 +136,18 @@ def handleLiveTreeContextMenu(name, sender, args):
 
         if False and object_selected and selection_type == 'db.Table':
             item = mforms.newMenuItem(_("Export Data to CSV File..."))
-            item.set_name("export_table_csv")
+            item.set_name("Export Table to CSV")
+            item.setInternalName("export_table_csv")
             menu.insert_item(index-1, item)
             index += 1
             item = mforms.newMenuItem(_("Import Data from CSV File..."))
-            item.set_name("import_table_csv")
+            item.set_name("Import Table to CSV")
+            item.setInternalName("import_table_csv")
             menu.insert_item(index-1, item)
             index += 1
             item = mforms.newMenuItem(_("Dump Data to SQL File..."))
-            item.set_name("dump_table")
+            item.set_name("Dump Table")
+            item.setInternalName("dump_table")
             menu.insert_item(index-1, item)
             index += 1
 
@@ -148,40 +155,42 @@ def handleLiveTreeContextMenu(name, sender, args):
             # Add menu items for generating code
             code_items = [
                           # Caption, callback name, supported node types, enable condition, mixed node types allowed
-                          (_("Name"), 'name_short', ['db.Schema'], len(selection) > 0, False),
-                          (_("Name (short)"), 'name_short', ['tables', 'views', 'functions', 'storedProcedures', 'db.Table', 'db.Table:db.Column', 'db.View:db.Column', 'db.View', 'db.StoredProcedure', 'db.Function'], len(selection) > 0, True),
-                          (_("Name (long)"), 'name_long', ['tables', 'views', 'functions', 'storedProcedures', 'db.Table', 'db.Table:db.Column', 'db.View:db.Column', 'db.View', 'db.StoredProcedure', 'db.Function'], len(selection) > 0, True),
-                          (_("Select All Statement"), 'select_all_statement', ['db.Table', 'db.View'], len(selection) > 0, False),
-                          (_("Select All Statement"), 'select_all_statement', ['columns'], len(selection) == 1 and selection[0].type == 'columns', False),
-                          (_("Select Columns Statement"), 'select_columns_statement', ['db.Table:db.Column', 'db.View:db.Column'], len(unique_tables) == 1, False),
-                          (_("Insert Statement"), 'insert_all_statement', ['db.Table', 'columns'], len(selection) > 0, False),
-                          (_("Insert Statement"), 'insert_columns_statement', ['db.Table:db.Column'], len(selection) > 0, False),
-                          (_("Update Statement"), 'update_all_statement', ['db.Table', 'columns'], len(selection) > 0, False),
-                          (_("Update Statement"), 'update_columns_statement', ['db.Table:db.Column'], len(selection) > 0, False),
-                          (_("Delete Statement"), 'delete_statement', ['db.Table'], len(selection) > 0, False),
-                          (_("Create Statement"), 'create_statement', ['db.Schema', 'db.Table', 'db.View', 'db.StoredProcedure', 'db.Function'], len(selection) > 0, False),
-                          (_("Procedure Call"), 'call_procedure', ['db.StoredProcedure'], len(selection) > 0, False),
-                          (_("Function Call"), 'call_function', ['db.Function'], len(selection) > 0, False),
-                          (None, None, ['db.Table'], None, False),
-                          (_("Join Selected Tables"), 'build_joined_select', ['db.Table'], len(selection) == 2, False),
-                          (_("Delete with References"), 'build_cascaded_delete', ['db.Table'], len(selection) == 1, False),
-                          (_("Select Row References"), 'build_cascaded_select', ['db.Table'], len(selection) == 1, False),
+                          (_("Name"), "Name", 'name_short', ['db.Schema'], len(selection) > 0, False),
+                          (_("Name (short)"), "Short Name", 'name_short', ['tables', 'views', 'functions', 'storedProcedures', 'db.Table', 'db.Table:db.Column', 'db.View:db.Column', 'db.View', 'db.StoredProcedure', 'db.Function'], len(selection) > 0, True),
+                          (_("Name (long)"), "Long Name", 'name_long', ['tables', 'views', 'functions', 'storedProcedures', 'db.Table', 'db.Table:db.Column', 'db.View:db.Column', 'db.View', 'db.StoredProcedure', 'db.Function'], len(selection) > 0, True),
+                          (_("Select All Statement"), "Select All Statement", 'select_all_statement', ['db.Table', 'db.View'], len(selection) > 0, False),
+                          (_("Select All Statement"), "Select All Statement", 'select_all_statement', ['columns'], len(selection) == 1 and selection[0].type == 'columns', False),
+                          (_("Select Columns Statement"), "Select Columns Statement", 'select_columns_statement', ['db.Table:db.Column', 'db.View:db.Column'], len(unique_tables) == 1, False),
+                          (_("Insert Statement"), "Insert Statement", 'insert_all_statement', ['db.Table', 'columns'], len(selection) > 0, False),
+                          (_("Insert Statement"), "Insert Statement", 'insert_columns_statement', ['db.Table:db.Column'], len(selection) > 0, False),
+                          (_("Update Statement"), "Update Statement", 'update_all_statement', ['db.Table', 'columns'], len(selection) > 0, False),
+                          (_("Update Statement"), "Update Statement", 'update_columns_statement', ['db.Table:db.Column'], len(selection) > 0, False),
+                          (_("Delete Statement"), "Delete Statement", 'delete_statement', ['db.Table'], len(selection) > 0, False),
+                          (_("Create Statement"), "Create Statement", 'create_statement', ['db.Schema', 'db.Table', 'db.View', 'db.StoredProcedure', 'db.Function'], len(selection) > 0, False),
+                          (_("Procedure Call"), "Procedure Call", 'call_procedure', ['db.StoredProcedure'], len(selection) > 0, False),
+                          (_("Function Call"), "Function Call", 'call_function', ['db.Function'], len(selection) > 0, False),
+                          (None, None, None, ['db.Table'], None, False),
+                          (_("Join Selected Tables"), "Join Selected Tables", 'build_joined_select', ['db.Table'], len(selection) == 2, False),
+                          (_("Delete with References"), "Delete With References", 'build_cascaded_delete', ['db.Table'], len(selection) == 1, False),
+                          (_("Select Row References"), "Select Row References", 'build_cascaded_select', ['db.Table'], len(selection) == 1, False),
                           ]
 
             copy_submenu = mforms.newMenuItem("Copy to Clipboard")
-            copy_submenu.set_name("copy_to_clipboard")
+            copy_submenu.set_name("Copy to Clipboard")
+            copy_submenu.setInternalName("copy_to_clipboard")
             menu.insert_item(index, copy_submenu)
             index += 1
 
             send_submenu = mforms.newMenuItem("Send to SQL Editor")
-            send_submenu.set_name("send_to_editor")
+            send_submenu.set_name("Send to Editor")
+            send_submenu.setInternalName("send_to_editor")
             menu.insert_item(index, send_submenu)
             index += 1
 
             gencopy = CodeGenerator(sender, selection, False)
             gensend = CodeGenerator(sender, selection, True)
 
-            for caption, name, types, enabled, allow_mixed in code_items:
+            for caption, accessibilityName, name, types, enabled, allow_mixed in code_items:
                 if not allow_mixed and mixed:
                     continue
                 if types and selection_type not in types:
@@ -190,11 +199,11 @@ def handleLiveTreeContextMenu(name, sender, args):
                     copy_submenu.add_separator()
                     send_submenu.add_separator()
                 else:
-                    item = copy_submenu.add_item_with_title(caption, getattr(gencopy, name), name)
-                    item.set_enabled(enabled)
+                    item = copy_submenu.add_item_with_title(caption, getattr(gencopy, name), accessibilityName, "")
+                    item.set_enabled(bool(enabled))
 
-                    item = send_submenu.add_item_with_title(caption, getattr(gensend, name), name)
-                    item.set_enabled(enabled)
+                    item = send_submenu.add_item_with_title(caption, getattr(gensend, name), accessibilityName, "")
+                    item.set_enabled(bool(enabled))
             needs_separator = True
         else:
             needs_separator = False
@@ -218,9 +227,20 @@ def handleLiveTreeContextMenu(name, sender, args):
                 #        if selection[0].type == 'tables':
                 #            it.set_enabled(False)
                 for templ in template_manager.templates:
-                    it = item.add_item_with_title(templ.name, lambda templ=templ, schema=selection[0].schemaName: template_manager.create_table_like_template(sender, schema, templ))
+                    item.add_item_with_title(templ.name, lambda templ=templ, schema=selection[0].schemaName: template_manager.create_table_like_template(sender, schema, templ), templ.name, "")
                 item.add_separator()
-                it = item.add_item_with_title("Edit Templates...", template_manager.edit_templates)
+                item.add_item_with_title("Edit Templates...", template_manager.edit_templates, "Edit Templates", "")
+                
+        if selection_type is None:
+            if needs_separator:
+                menu.insert_item(index, mforms.newMenuItem("", mforms.SeparatorMenuItem))
+                index += 1
+                needs_separator = False
+
+            item = mforms.newMenuItem("Create Schema...")
+            item.add_clicked_callback(lambda: do_create_object(sender, None, "db.Schema"))
+            menu.insert_item(index, item)
+            index+= 1
 
         if object_selected:
             if needs_separator:
@@ -268,6 +288,16 @@ def handleLiveTreeContextMenu(name, sender, args):
             item.add_clicked_callback(lambda: open_search(sender))
             insert_item_to_plugin_context_menu(menu, item)
 
+        if selection_type == 'db.Table:db.Column' and column_selected:
+            if needs_separator:
+                menu.insert_item(index, mforms.newMenuItem("", mforms.SeparatorMenuItem))
+                index += 1
+                needs_separator = False
+            item = mforms.newMenuItem("Create Index...")
+            item.add_clicked_callback(lambda: do_create_index(sender, selection))
+            menu.insert_item(index, item)
+            index += 1
+
 
 def open_search(editor):
     grt.modules.MySQLDBSearchModule.showSearchPanel(editor)
@@ -275,73 +305,9 @@ def open_search(editor):
 
 def do_create_object(editor, schema_name, db_type):
     if db_type == 'db.Schema':
-        ocatalog = grt.classes.db_mysql_Catalog()
-        ocatalog.name = 'default'
-        ocatalog.oldName = ocatalog.name
-        ocatalog.simpleDatatypes.extend(grt.root.wb.rdbmsMgmt.rdbms[0].simpleDatatypes)
-
-        catalog = grt.classes.db_mysql_Catalog()
-        catalog.name = 'default'
-        catalog.oldName = catalog.name
-        catalog.simpleDatatypes.extend(grt.root.wb.rdbmsMgmt.rdbms[0].simpleDatatypes)
-
-        schema = grt.classes.db_mysql_Schema()
-        schema.name = "new_schema"
-        schema.oldName = ""
-        schema.owner = catalog
-        catalog.schemata.append(schema)
-
-        editor.editLiveObject(schema, ocatalog)
+        editor.alterLiveObject(db_type, "", "")
     else:
-        ocatalog = grt.classes.db_mysql_Catalog()
-        ocatalog.name = 'default'
-        ocatalog.oldName = ocatalog.name
-        ocatalog.simpleDatatypes.extend(grt.root.wb.rdbmsMgmt.rdbms[0].simpleDatatypes)
-
-        oschema = grt.classes.db_mysql_Schema()
-        oschema.name = schema_name
-        oschema.oldName = oschema.name
-        oschema.owner = ocatalog
-        ocatalog.schemata.append(oschema)
-
-        catalog = grt.classes.db_mysql_Catalog()
-        catalog.name = 'default'
-        catalog.oldName = catalog.name
-        catalog.simpleDatatypes.extend(grt.root.wb.rdbmsMgmt.rdbms[0].simpleDatatypes)
-
-        schema = grt.classes.db_mysql_Schema()
-        schema.name = schema_name
-        schema.oldName = schema.name
-        schema.owner = catalog
-        catalog.schemata.append(schema)
-
-        if db_type == 'db.Table':
-            newobj = grt.classes.db_mysql_Table()
-            newobj.owner = schema
-            newobj.name = "new_table"
-            schema.tables.append(newobj)
-        elif db_type == 'db.StoredProcedure':
-            newobj = grt.classes.db_mysql_Routine()
-            newobj.routineType = 'procedure'
-            newobj.owner = schema
-            newobj.name = "new_procedure"
-            schema.routines.append(newobj)
-        elif db_type == 'db.Function':
-            newobj = grt.classes.db_mysql_Routine()
-            newobj.routineType = 'function'
-            newobj.owner = schema
-            newobj.name = "new_function"
-            schema.routines.append(newobj)
-        elif db_type == 'db.View':
-            newobj = grt.classes.db_mysql_View()
-            newobj.owner = schema
-            newobj.name = "new_view"
-            schema.views.append(newobj)
-        else:
-            print "Unsupported objtype", db_type
-            return
-        editor.editLiveObject(newobj, ocatalog)
-
+        editor.alterLiveObject(db_type, schema_name, "")
 
 def do_alter_object(editor, selection):
     for obj in selection:
@@ -417,6 +383,27 @@ def do_truncate_table(editor, selection):
     mforms.App.get().set_status_text("%i tables truncated" % count)
 
 
+def do_create_index(editor, selection):
+    cols = []
+    schema = None
+    table = None
+    for node in selection:
+        if schema and schema != node.schemaName:
+            mforms.Utilities.show_error("Create Index", "Please select one or more columns from the same table.", "OK", "", "")
+            return
+        if table and (not node.owner or table != node.owner.name):
+            mforms.Utilities.show_error("Create Index", "Please select one or more columns from the same table.", "OK", "", "")
+            return
+        schema = node.schemaName
+        table = node.owner.name
+        cols.append(node.name)
+    if cols:
+        form = CreateIndexForm(mforms.Form.main_form(), editor, schema, table, cols, None)
+        if form.run():
+            pass
+
+
+
 def do_drop_object(editor, selection):
     statements = []
     table_names = []
@@ -489,19 +476,20 @@ def do_drop_object(editor, selection):
                                              "Please confirm permanent deletion of %s `%s`." % (list(object_types)[0].lower(), selection[0].name),
                                              "Review SQL", "Cancel", "Drop Now")
         else:
-            res = mforms.Utilities.show_message("Drop Objects", "Please confirm permanent deletion of %s %s objects: %s" % (count, ", ".join(list(object_types), ", ".join([s.name for s in selection]))),
+            res = mforms.Utilities.show_message("Drop Objects", "Please confirm permanent deletion of %s %s objects: %s" % (count, ", ".join(list(object_types)), ", ".join([s.name for s in selection])),
                                              "Review SQL", "Cancel", "Drop Now")
     if res is None or res == mforms.ResultCancel:
         return
 
     if res == mforms.ResultOk:
-        if not review_sql_code("\n".join([stmt+";" for c, stmt in statements])):
+        if not review_sql_code("\n".join([s+";" for c, s in statements])):
             return
 
     drop_count = 0
     for i, (c, stmt) in enumerate(statements):
         try:
-            editor.executeManagementCommand(stmt, 1)
+            #This should be run in background because of the bug: #71327
+            editor.executeCommand(stmt,1 ,1)
             drop_count += c
         except Exception, exc:
             if i < len(statements)-1:
@@ -529,7 +517,7 @@ class DependencyAnalyzer:
             return None
         m.connect(connection, password)
 
-        grt.log_info("sqlide_grt", "Reverse engineering schema %s..." % self.schema_name)
+        grt.log_info("sqlide_grt", "Reverse engineering schema %s...\n" % self.schema_name)
         options = {"reverseEngineerTables" : True,
             "reverseEngineerTriggers" : False,
             "reverseEngineerViews" : False,
@@ -537,6 +525,7 @@ class DependencyAnalyzer:
         self.catalog = m.reverseEngineer(connection, "", [self.schema_name], options)
 
         m.disconnect(connection)
+        grt.log_info("sqlide_grt", "Reverse engineer schema %s finished\n" % self.schema_name)
 
         return self.catalog
 
@@ -598,6 +587,8 @@ class DependencyAnalyzer:
         distance[from_table] = 0
 
         def relax(u, v):
+            if u not in distance or v not in distance:
+                return
             if distance[v] > distance[u] + 1:
                 distance[v] = distance[u] + 1
                 predecessor[v] = u
@@ -637,6 +628,8 @@ def dependencyInfoForSchemaInEditor(editor, schema):
             mforms.App.get().set_status_text("Cancelled.")
             return
 
+        mforms.App.get().set_status_text("%s reverse engineered" % schema)
+
         editor.customData["sqlide_grt:Catalog:%s" % schema] = catalog
     else:
         mforms.App.get().set_status_text("Reusing reverse engineered schema for %s..." % schema)
@@ -767,7 +760,6 @@ class CodeGenerator:
 
     def select_columns_statement(self):
         # assumes only column nodes or Columns parent node, all of a single unique table
-        parts = []
         columns = []
         table = None
         for obj in self.selection:
@@ -823,6 +815,7 @@ class CodeGenerator:
 
     def create_statement(self):
         parts = []
+        delimiter = grt.root.wb.options.options['SqlDelimiter']
         for obj in self.selection:
             wrapper = "%s;\n"
             if obj.type == 'db.Schema':
@@ -834,15 +827,15 @@ class CodeGenerator:
             elif obj.type == 'db.Trigger':
                 rs = self.editor.executeManagementQuery("SHOW CREATE TRIGGER %s.%s" % (esc_ident(obj.schemaName), esc_ident(obj.name)), 0)
                 field_name = 'Statement'
-                wrapper = "DELIMITER $$\n%s$$\nDELIMITER ;\n"
+                wrapper = "DELIMITER " + delimiter + "\n%s" + delimiter + "\nDELIMITER ;\n"
             elif obj.type == 'db.StoredProcedure':
                 rs = self.editor.executeManagementQuery("SHOW CREATE PROCEDURE %s.%s" % (esc_ident(obj.schemaName), esc_ident(obj.name)), 0)
                 field_name = 'Create Procedure'
-                wrapper = "DELIMITER $$\n%s$$\nDELIMITER ;\n"
+                wrapper = "DELIMITER " + delimiter + "\n%s" + delimiter + "\nDELIMITER ;\n"
             elif obj.type == 'db.Function':
                 rs = self.editor.executeManagementQuery("SHOW CREATE FUNCTION %s.%s" % (esc_ident(obj.schemaName), esc_ident(obj.name)), 0)
                 field_name = 'Create Function'
-                wrapper = "DELIMITER $$\n%s$$\nDELIMITER ;\n"
+                wrapper = "DELIMITER " + delimiter + "\n%s" + delimiter + "\nDELIMITER ;\n"
             elif obj.type == 'db.View':
                 rs = self.editor.executeManagementQuery("SHOW CREATE VIEW %s.%s" % (esc_ident(obj.schemaName), esc_ident(obj.name)), 0)
                 field_name = 'Create View'
@@ -940,6 +933,11 @@ class CodeGenerator:
             mforms.Utilities.show_error("Select Row References", "Could not find reverse engineered %s" % object.name, "OK", "", "")
             return
 
+        if not the_table.primaryKey:
+            mforms.Utilities.show_error("Select Row References", "Unable to find referencing tables for %s because the table has no primary key." % object.name,
+                                      "OK", "", "")
+            return
+
         # expression to match the row
         pk = []
         for c in the_table.primaryKey.columns:
@@ -1001,6 +999,11 @@ class CodeGenerator:
             mforms.Utilities.show_error("Cascading DELETE", "Could not find reverse engineered %s" % object.name, "OK", "", "")
             return
 
+        if not the_table.primaryKey:
+            mforms.Utilities.show_error("Cascading DELETE", "Unable to create a DELETE statement for %s because the table has no primary key." % object.name,
+                                        "OK", "", "")
+            return
+
         # expression to match the row to be deleted
         pk = []
         for c in the_table.primaryKey.columns:
